@@ -498,7 +498,7 @@ unsigned int RangeFile::write(std::ostream &f, size_t format) const
 					
 					f << "Range" << ui+1 <<"=" 
 					<< ranges[ui].first << " " << ranges[ui].second <<
-					" " << "Name:" << strName << ":1" << 
+					" " << "Name:" << strName << " " << strName << ":1" << 
 					" Color:" << colString << endl;
 
 				}
@@ -1118,7 +1118,7 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 			getline(f,tmpStr);
 
 			//shouldn't hit eof
-			if(f.eof())
+			if(f.eof() || (!f.good()) )
 			{
 				tmpStr.clear();
 				break;
@@ -1134,10 +1134,10 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 		}
 
 		//Now, spin forwards until we either hit EOF or our double-dash marker
-
-		while(!f.eof())
+		while( ! (f.eof() || f.bad()) )
 		{
-			getline(f,tmpStr);
+			if(!getline(f,tmpStr))
+				break;
 
 			if(tmpStr.size() > 2 &&
 				tmpStr[0] == '-' && tmpStr[1] == '-')
@@ -1149,7 +1149,7 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 			}
 		}
 
-		if(f.eof())
+		if(!f.good())
 		{
 			//we did not see a double-dash, must be a vanilla ORNL file
 			typeStatus[RANGE_FORMAT_DBL_ORNL]=STATUS_IS_NOT;
@@ -1179,7 +1179,7 @@ skipoutRNGChecks:
 		bool foundAllSections=false;
 
 		//Scan through each line, looking for a matching section header
-		while(!f.eof())
+		while((!f.eof()) &&f.good())
 		{
 
 			//Get line, stripped of whitespace
@@ -1505,6 +1505,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 	bool beyondRanges=false;
 	bool haveNumRanges=false;	
 	bool haveNameBlock=false;	
+	bool haveSeenRevHeader=false;	
 	vector<string> strVec;
 
 	//Read file until we get beyond the range length
@@ -1527,6 +1528,13 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 		if(!s.size())
 			continue;
 
+		//If we have
+		if(!haveSeenRevHeader && (s== "Rev_2.0"))
+		{
+			haveSeenRevHeader=true;
+			continue;
+		}
+
 		//Try different delimiters to split string
 		splitStrsRef(s.c_str(),"\t ",strVec);
 
@@ -2422,6 +2430,24 @@ void RangeFile::rangeByRangeID(vector<IonHit> &ions, unsigned int rangeID)
 	ions.swap(rangedVec);
 }
 
+void RangeFile::rangeByIon(const std::vector<IonHit> & ions,
+			const vector<bool> &selectedIons, vector<IonHit> &output) const
+{
+	output.clear();
+
+	//TODO: Play with openmp, to see if this is faster.
+	// There will be problems with synchronising writes to the output.
+	// Could try a sampling algorithm to estimate output size
+	for(size_t ui=0;ui<ions.size();ui++)
+	{
+		unsigned int id;
+		id=getIonID(ions[ui].getMassToCharge());
+		if(id == (unsigned int)-1)
+			continue;
+		if(selectedIons[id])
+			output.push_back(ions[ui]);
+	}
+}
 
 void RangeFile::printErr(std::ostream &strm) const
 {
