@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2013  D Haley
+ * Copyright (C) 2015  D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -353,3 +353,76 @@ void AbundanceData::getSymbolIndices(const vector<string> &symbols,vector<size_t
 		indices[ui]=symbolIndex(symbols[ui].c_str());
 }
 
+
+#ifdef DEBUG
+
+#include <set>
+
+using std::set;
+
+void AbundanceData::checkErrors() const
+{
+	//Ensure all isotopes sum to 1-ish
+	// Rounding errors limit our correctness here.
+	for(size_t ui=0;ui<isotopeData.size();ui++)
+	{
+		if(!isotopeData[ui].size())
+			continue;
+
+		float sum;
+		sum=0.0f;
+		for(size_t uj=0; uj<isotopeData[ui].size();uj++)
+		{
+			sum+=isotopeData[ui][uj].abundance;
+		}
+
+		ASSERT(fabs(sum -1.0f) < 0.000001);
+
+	}
+
+
+	//Ensure Ti has 5 isotopes (original data file was missing)
+	ASSERT(isotopeData[symbolIndex("Ti")].size() == 5);
+
+	//Enusre all isotopes are uniquely numbered
+	// - loop over each atom
+	for(size_t ui=0;ui<isotopeData.size();ui++)
+	{
+		//now ovre each isotope
+		std::set<size_t> uniqNums;
+		uniqNums.clear();
+		for(size_t uj=0; uj<isotopeData[ui].size();uj++)
+		{
+			ASSERT(uniqNums.find(isotopeData[ui][uj].massNumber) == uniqNums.end());
+			uniqNums.insert(isotopeData[ui][uj].massNumber);
+			
+		}
+	}
+}
+
+bool AbundanceData::runUnitTests(const char *tableFile)
+{
+	AbundanceData massTable;
+	TEST(massTable.open(tableFile) == 0,"load table");
+	//FIXME: Getting the isotope dis
+
+	size_t ironIndex=massTable.symbolIndex("Fe");
+	TEST(ironIndex != (size_t)-1,"symbol lookup");
+
+	//Generate the mass peak dist for iron
+	vector<size_t> elements;
+	vector<size_t> concentrations;
+	elements.push_back(ironIndex);
+	concentrations.push_back(1);
+
+	std::vector<std::pair<float,float> > massDist;
+	massTable.generateIsotopeDist(elements,concentrations,massDist);
+
+	TEST(massDist.size() == 4, "Iron has 4 isotopes");
+
+	massTable.checkErrors();
+
+	return true;	
+
+}
+#endif
