@@ -1,6 +1,6 @@
 /*
  *	configFile.cpp  - User configuration loading/saving
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ const unsigned int MAX_MOUSE_PERCENT= 400;
 
 using std::endl;
 using std::string;
+using std::deque;
 
 
 ConfigFile::ConfigFile() : configLoadOK(false), panelMode(CONFIG_PANELMODE_REMEMBER),
@@ -521,7 +522,7 @@ nodeptrEndJump:
 
 bool ConfigFile::createConfigDir()
 {
-	wxString filePath = wxStr(getConfigDir());
+	wxString filePath = (getConfigDir());
 
 	//Create the folder if it does not exist
 	if(!wxDirExists(filePath))
@@ -540,14 +541,8 @@ bool ConfigFile::createConfigDir()
 
 std::string ConfigFile::getConfigDir() 
 {
-#if wxCHECK_VERSION(2,9,0)
  	wxStandardPaths &paths = wxStandardPaths::Get();
-	wxString filePath = paths.GetDocumentsDir()+wxCStr("/.")+wxCStr(PROGRAM_NAME);
-#else
-	wxStandardPaths *paths = new wxStandardPaths;
-	wxString filePath = paths->GetDocumentsDir()+wxCStr("/.")+wxCStr(PROGRAM_NAME);
-	delete paths;
-#endif
+	wxString filePath = paths.GetDocumentsDir()+("/.")+(PROGRAM_NAME);
 	return stlStr(filePath);
 }
 
