@@ -193,7 +193,7 @@ unsigned int GetReducedHullPts(const vector<Point3D> &points, float reductionDim
 
 	unsigned int dummyProg;
 	vector<Point3D> theHull;
-	if(computeConvexHull(points,progress,wantAbort,theHull,false))
+	if(computeConvexHull(points,progress,wantAbort,theHull,false,false))
 		return 2;
 
 	Point3D midPoint(0,0,0);
@@ -1044,5 +1044,16 @@ void generateKnnTheoreticalDist(const std::vector<float> &radii, float density,
 
 }
 
+bool qhullTest()
+{
+#if defined(__WIN64)
+	//If using a cross-compile (at least)
+	// qhull under win64 must use long long, or we get random crashes
+	// The definition is set in qhull/mem.h
+	COMPILE_ASSERT(sizeof(ptr_intT) == sizeof(long long))
+#endif
+
+	return true;
+}
 
 
