@@ -20,7 +20,7 @@
 #include "boundingBox.h"
 #include "ionDownsample.h"
 #include "dataLoad.h"
-#include "compositionProfile.h"
+#include "profile.h"
 #include "externalProgram.h"
 #include "ionClip.h"
 #include "ionColour.h"
