@@ -1,6 +1,6 @@
 /*
  *	annotation.h - 3D annotation header
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ class AnnotateFilter : public Filter
 		float textSize,annotateSize,sphereMarkerSize,lineSize;
 
 		//Annotation colour
-		float r,g,b,a;
+		ColourRGBAf rgba;
 
 		//Disable/enable annotation
 		bool active;
@@ -85,7 +85,7 @@ class AnnotateFilter : public Filter
 		// ->cached.
 		unsigned int refresh(const std::vector<const FilterStreamData *> &dataIn,
 							std::vector<const FilterStreamData *> &dataOut,
-							ProgressData &progress, bool (*callback)(bool));
+							ProgressData &progress);
 		//!Get (approx) number of bytes required for cache
 		size_t numBytesForCache(size_t nObjects) const;
 
@@ -107,7 +107,7 @@ class AnnotateFilter : public Filter
 		void setPropFromBinding( const SelectionBinding &b) ;
 
 		//!Get the human readable error string associated with a particular error code during refresh(...)
-		std::string getErrString(unsigned int code) const;
+		std::string getSpecificErrString(unsigned int code) const;
 
 		//!Dump state to output stream, using specified format
 		/* Current supported formats are STATE_FORMAT_XML
