@@ -19,6 +19,7 @@
 #include "filterCommon.h"
 
 #include <queue>
+#include <algorithm>
 
 #include <gsl/gsl_linalg.h>
 #include <gsl/gsl_eigen.h>
@@ -54,6 +55,7 @@ enum
 	KEY_SIZE_COUNT_BULK,
 	KEY_CROP_NMIN,
 	KEY_CROP_NMAX,
+	KEY_BULK_ALL,
 	KEY_CORE_OFFSET=100000,
 	KEY_BULK_OFFSET=200000
 };
@@ -90,6 +92,11 @@ using std::vector;
 const float SPHERE_PRESEARCH_CUTOFF = 75;
 
 
+//In link clustering, when we preform size cropping, do we awant to count bulk ions in our analysis?
+const bool WANT_COUNT_BULK_FORCROP=false;
+
+
+
 void makeFrequencyTable(const IonStreamData *i ,const RangeFile *r, 
 				std::vector<std::pair<string,size_t> > &freqTable) 
 {
@@ -102,6 +109,9 @@ void makeFrequencyTable(const IonStreamData *i ,const RangeFile *r,
 #else
 	numThreads=1;
 #endif
+
+	//Create a series of independent vectors,that we can sum into seperately,
+	// based upon the number of threads
 	vector<size_t *> ionHist;
 	ionHist.resize(numThreads);
 
@@ -147,6 +157,8 @@ void makeFrequencyTable(const IonStreamData *i ,const RangeFile *r,
 	for(size_t uj=0;uj<r->getNumIons();uj++)
 		freqTable.push_back(make_pair(r->getName(uj),ionHist[0][uj]));
 
+	for(size_t ui=0;ui<numThreads;ui++)
+		delete[] ionHist[ui];
 }
 
 void makeCompositionTable(const IonStreamData *i ,const RangeFile *r, 
@@ -264,8 +276,6 @@ ClusterAnalysisFilter::ClusterAnalysisFilter() : algorithm(CLUSTER_LINK_ERODE),
 	wantClusterMorphology(false), haveRangeParent(false)
 
 {
-	//haveRangeParent=false; //Initialiser sets this to false, as required by ::initFilter
-
 	cacheOK=false;
 
 	//By default, we should cache, but final decision is made higher up
@@ -557,7 +567,7 @@ unsigned int ClusterAnalysisFilter::refresh(const std::vector<const FilterStream
 		paranoidDebugAssert(clusteredCore,clusteredBulk);
 #endif
 	if(wantCropSize)
-		stripClusterBySize(clusteredCore,clusteredBulk,progress);
+		stripClusterBySize(clusteredCore,clusteredBulk,WANT_COUNT_BULK_FORCROP,progress);
 
 	bool haveBulk,haveCore;
 	haveBulk=clusteredBulk.size();
@@ -800,20 +810,30 @@ ASSERT(!(haveBulk && !haveCore));
 	if(wantClusterID)
 	{
 
+		//To prevent clusters ID from correlatiing with their position
+		// which results in odd visual effects, randomise the ID a litlle;
+		vector<size_t> idShuffle;
+		idShuffle.resize(clusteredCore.size());
+
+		for(unsigned int ui=0;ui<idShuffle.size();ui++)
+			idShuffle[ui]=ui;
+
+		std::random_shuffle(idShuffle.begin(),idShuffle.end());
+
 		#pragma omp parallel
 		{
 		#pragma omp for
 		for(size_t ui=0;ui<clusteredCore.size();ui++)
 		{
 			for(size_t uj=0;uj<clusteredCore[ui].size();uj++)
-				clusteredCore[ui][uj].setMassToCharge(ui);
+				clusteredCore[ui][uj].setMassToCharge(idShuffle[ui]);
 		}
 	
 		#pragma omp for
 		for(size_t ui=0;ui<clusteredBulk.size();ui++)
 		{
 			for(size_t uj=0;uj<clusteredBulk[ui].size();uj++)
-				clusteredBulk[ui][uj].setMassToCharge(ui);
+				clusteredBulk[ui][uj].setMassToCharge(idShuffle[ui]);
 		}
 		}
 	}
@@ -985,23 +1005,23 @@ void ClusterAnalysisFilter::getProperties(FilterPropGroup &propertyList) const
 			p.helpText=TRANS("Distance from core points that form cluster that is used to grab surrounding bulk points");
 			p.key=KEY_BULKLINK;
 			propertyList.addProperty(p,curGroup);
-		}
 		
-		p.name=TRANS("Erosion");
-		p.data=boolStrEnc(enableErosion);
-		p.type=PROPERTY_TYPE_BOOL;
-		p.helpText=TRANS("Enable  linking of non-cluster species - eg for composition analysis ");
-		p.key=KEY_ERODE_ENABLE;
-		propertyList.addProperty(p,curGroup);
-		if(enableErosion)
-		{
-			stream_cast(tmpStr,dErosion);
-			p.name=TRANS("Erode Dist");
-			p.data=tmpStr;
-			p.type=PROPERTY_TYPE_REAL;
-			p.helpText=TRANS("Distance from unclustered material in which bulk points are eroded from cluster");
-			p.key=KEY_ERODEDIST;
+			p.name=TRANS("Erosion");
+			p.data=boolStrEnc(enableErosion);
+			p.type=PROPERTY_TYPE_BOOL;
+			p.helpText=TRANS("Enable  linking of non-cluster species - eg for composition analysis ");
+			p.key=KEY_ERODE_ENABLE;
 			propertyList.addProperty(p,curGroup);
+			if(enableErosion)
+			{
+				stream_cast(tmpStr,dErosion);
+				p.name=TRANS("Erode Dist");
+				p.data=tmpStr;
+				p.type=PROPERTY_TYPE_REAL;
+				p.helpText=TRANS("Distance from unclustered material in which bulk points are eroded from cluster");
+				p.key=KEY_ERODEDIST;
+				propertyList.addProperty(p,curGroup);
+			}
 		}
 	}
 	
@@ -1098,7 +1118,7 @@ void ClusterAnalysisFilter::getProperties(FilterPropGroup &propertyList) const
 	
 	curGroup++;
 
-	if(haveRangeParent)
+	if(haveRangeParent && ionNames.size())
 	{	
 		//Offset markers are used elsewhere. Must be in sync with
 		//this code	
@@ -1123,6 +1143,16 @@ void ClusterAnalysisFilter::getProperties(FilterPropGroup &propertyList) const
 
 		if(enableBulkLink)
 		{
+			
+			p.name=TRANS("Enable/Disable All");
+			bool allEnabled=false;
+			allEnabled=(std::find(ionBulkEnabled.begin(),ionBulkEnabled.end(),false) == ionBulkEnabled.end());
+			p.data=boolStrEnc(allEnabled);
+			p.type=PROPERTY_TYPE_BOOL;
+			p.helpText=TRANS("Enable/disable all ions");
+			p.key=KEY_BULK_ALL;
+			propertyList.addProperty(p,curGroup);
+
 			for(size_t ui=0;ui<ionNames.size();ui++)
 			{
 				if(ionBulkEnabled[ui])
@@ -1483,6 +1513,20 @@ bool ClusterAnalysisFilter::setProperty(unsigned int key,
 			
 			break;
 		}
+		case KEY_BULK_ALL:
+		{
+			ASSERT(enableBulkLink);
+			bool bVal;
+			boolStrDec(value,bVal);
+			std::fill(ionBulkEnabled.begin(),ionBulkEnabled.end(),bVal);
+		
+			//we have to maintain the core selection, so that
+			//both core and bulk are not set at the same time
+			if(bVal)
+				std::fill(ionCoreEnabled.begin(),ionCoreEnabled.end(),!bVal);
+
+			break;
+		}
 		default:
 		{
 			ASSERT( key >=KEY_CORE_OFFSET);
@@ -1864,12 +1908,13 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 	//
 	// In the implementation, there are more steps, due to data structure construction
 	// and other computational concerns
+
 	
 	bool needErosion=enableErosion && enableBulkLink;
 	unsigned int numClusterSteps=4;
 	if(enableBulkLink)
 		numClusterSteps+=2;
-	if(needErosion)
+	if(needErosion && enableBulkLink)
 		numClusterSteps++;
 	if(enableCoreClassify)
 		numClusterSteps++;
@@ -1961,13 +2006,10 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		
 
 	vector<vector<size_t> > allCoreClusters,allBulkClusters;
-	const float linkDistSqr=linkDist*linkDist;
-	
 	//When this queue is exhausted, move to the next cluster
 	for(size_t ui=0;ui<coreTree.size();ui++)
 	{
 		size_t curPt;
-		float curDistSqr;
 		//Indicies of each cluster
 		vector<size_t> soluteCluster,dummy;
 		//Queue for atoms in this cluster waiting to be checked
@@ -1981,66 +2023,51 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		coreTree.tag(ui);
 
 	
-	
-		size_t clustIdx;
+		//If the atom is not clustered, use it as a point from 
+		//which we start a search	
 		thisClusterQueue.push(ui);
 		soluteCluster.push_back(ui);
+	
+		//Keep looping throughe queue until it is exhausted
 		do
 		{
+			//search atom's position
 			curPt=thisClusterQueue.front();
-			const Point3D *thisPt;
-			thisPt=coreTree.getPt(curPt);
-			curDistSqr=0;
 
+			//Find all the points in a sphere around this one
+			vector<size_t> nnIdxs;
+			coreTree.ptsInSphere(*(coreTree.getPt(curPt)),linkDist,nnIdxs);
 
-
-			//Now loop over this solute's NNs not found by prev. method
-			while(true)
+			//Loop over this solute's NNs
+			for(size_t uj=0;uj<nnIdxs.size();uj++)
 			{
+				size_t clustIdx;
 				ASSERT(curPt < coreTree.size());
-				//Find the next point that we have not yet retrieved
+				//Find the next point that we have not yet retreived
 				//the find will tag the point, so we won't see it again
 				ASSERT(bCore.isValid());
-				clustIdx=coreTree.findNearestUntagged(
-						*thisPt,bCore, true);
+				clustIdx=nnIdxs[uj];
 
+				//Record it as part of the cluster	
 
-				ASSERT(clustIdx == (size_t)-1 || coreTree.getTag(clustIdx));
-				if(clustIdx != (size_t)-1)
+				if(!coreTree.getTag(clustIdx))
 				{
-					curDistSqr=coreTree.getPt(clustIdx)->sqrDist(
-							*(coreTree.getPt(curPt)) );
-
-				}
-
-				//Point out of clustering range, or no more points
-				if(clustIdx == (size_t)-1 || curDistSqr > linkDistSqr)
-				{
-					//If the point was not tagged,
-					//Un-tag the point; as it was too far away
-					if(clustIdx !=(size_t)-1)
-						coreTree.tag(clustIdx,false);
-					
-					thisClusterQueue.pop();
-					break;
-				}
-				else
-				{
-					//Record it as part of the cluster	
 					thisClusterQueue.push(clustIdx);
 					soluteCluster.push_back(clustIdx);
+					//tag point as visited
+					coreTree.tag(clustIdx);
 				}
-			
-
-				//Progress may be a little non-linear if cluster sizes are not random
-				progress.filterProgress= (unsigned int)(((float)ui/(float)coreTree.size())*100.0f);
-				if(*Filter::wantAbort)
-					return FILTER_ERR_ABORT;
 			}
 
 
-		} // Keep looping whilst we have coreTree to cluster.
-		while(!thisClusterQueue.empty() && clustIdx !=(size_t)-1);
+			//Progress may be a little non-linear if cluster sizes are not random
+			progress.filterProgress= (unsigned int)(((float)ui/(float)coreTree.size())*100.0f);
+			if(*Filter::wantAbort)
+				return FILTER_ERR_ABORT;
+
+			thisClusterQueue.pop();
+
+		}while(!thisClusterQueue.empty());
 			
 
 		if(soluteCluster.size())
@@ -2059,7 +2086,7 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		return FILTER_ERR_ABORT;
 
 	//NOTE : Speedup trick. If we know the cluster size at this point
-	// and we know we don't want to count the bulk, we can strip out clusters
+	// we can strip out clusters
 	// now, as we are going to do that anyway as soon as we return from our cluster
 	// computation.
 	// The advantage to doing it now is that we can (potentially) drop lots of clusters
@@ -2070,7 +2097,9 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		{
 			size_t count;
 			count =allCoreClusters[ui].size();
-			if(count < nMin || count > nMax)
+			//If we are not counting the bulk, then we can check nMin,
+			// as we know the cluster wont get any larger
+			if( (!WANT_COUNT_BULK_FORCROP && count < nMin ) || count > nMax)
 			{
 				allCoreClusters.back().swap(allCoreClusters[ui]);
 				allCoreClusters.pop_back();
@@ -2102,19 +2131,13 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		{
 			bulkTree.getBoundCube(bBulk);
 
-			//Compute the expected number of points that we would encapsulate
-			//if we were to place  a sphere of size bulkLink in the KD domain.
-			// This allows us to choose whether to use a bulk "grab" approach, or not.
-			bool expectedPtsInSearchEnough;
-			expectedPtsInSearchEnough=((float)bulkTree.size())/bBulk.volume()*4.0/3.0*M_PI*pow(bulkLink,3.0f)> SPHERE_PRESEARCH_CUTOFF;
-
 			//So-called "envelope" step.
-			float bulkLinkSqr=bulkLink*bulkLink;
 			size_t prog=PROGRESS_REDUCE;
 			//Now do the same thing with the matrix, but use the clusters as the "seed"
 			//positions
 			for(size_t ui=0;ui<allCoreClusters.size();ui++)
 			{
+
 				//The bulkTree component of the cluster
 				vector<size_t> thisBulkCluster,dummy;
 				for(size_t uj=0;uj<allCoreClusters[ui].size();uj++)
@@ -2122,84 +2145,38 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 					size_t curIdx;
 					curIdx=allCoreClusters[ui][uj];
 
-					const Point3D *curPt;
-					curPt=(coreTree.getPt(curIdx));
+					//Scan for bulkTree NNs.
+					vector<size_t> nnIdxs;
+					bulkTree.ptsInSphere(*(coreTree.getPt(curIdx)),bulkLink,nnIdxs);
 
-
-					//First do a grab of any sub-regions for cur pt
-					// based upon intersecting KD regions
-					// For readability, I have not factored this
-					// out of the loop; it should not have  a giant performance
-					// cost.
-					//---
-					if(expectedPtsInSearchEnough)
-					{
-						vector<pair<size_t,size_t> > blocks;
-						bulkTree.getTreesInSphere(*curPt,bulkLinkSqr,bBulk,blocks);
-
-						for(size_t uj=0; uj<blocks.size();uj++)
-						{
-							for(size_t uk=blocks[uj].first; uk<=blocks[uj].second;uk++)
-							{
-								if(!bulkTree.getTag(uk))
-								{
-									//Tag, then record it as part of the cluster	
-									bulkTree.tag(uk);
-									thisBulkCluster.push_back(uk);
-								}
-							}
-
-						}
-					}
-
-					//--
-
-
-
-					//Scan for bulkTree NN.
-					while(true)
+					//loop over the points we found
+					for(unsigned int uj=0;uj<nnIdxs.size();uj++)
 					{
 						size_t bulkTreeIdx;
-						float curDistSqr;
-						//Find the next point that we have not yet retrieved
-						//the find will tag the point, so we won't see it again
-						bulkTreeIdx=bulkTree.findNearestUntagged(
-								*curPt,bBulk, true);
-			
+						bulkTreeIdx=nnIdxs[uj];
+				
+						ASSERT(bulkTree.getPt(nnIdxs[uj])->sqrDist(
+						*(coreTree.getPt(curIdx)))< bulkLink*bulkLink);
+						if(bulkTree.getTag(bulkTreeIdx))
+							continue;
 
-						if(bulkTreeIdx !=(size_t)-1)
-						{
-							curDistSqr=bulkTree.getPt(
-								bulkTreeIdx)->sqrDist(*curPt);
-						}
-
-						//Point out of clustering range, or no more points
-						if(bulkTreeIdx == (size_t)-1 || curDistSqr > bulkLinkSqr )
-						{
-							//Un-tag the point; as it was too far away
-							if(bulkTreeIdx !=(size_t)-1)
-								bulkTree.tag(bulkTreeIdx,false);
-							break;
-						}
-						else
-						{
-							//Record it as part of the cluster	
-							thisBulkCluster.push_back(bulkTreeIdx);
-						}
-					
-						prog--;	
-						if(!prog)
-						{
-							prog=PROGRESS_REDUCE;
-							//Progress may be a little non-linear if cluster sizes are not random
-							progress.filterProgress= (unsigned int)(((float)ui/(float)allCoreClusters.size())*100.0f);
-							if(*Filter::wantAbort)
-								return FILTER_ERR_ABORT;
-
-						}
+						//Record as part of the cluster	
+						thisBulkCluster.push_back(bulkTreeIdx);
+						bulkTree.tag(bulkTreeIdx);
 					}
 
-					
+						
+					//Update progress data as needed	
+					if(prog <=nnIdxs.size())
+					{
+						prog=PROGRESS_REDUCE;
+						//Progress may be a little non-linear if cluster sizes are not random
+						progress.filterProgress= (unsigned int)(((float)ui/(float)allCoreClusters.size())*100.0f);
+						if(*Filter::wantAbort)
+							return FILTER_ERR_ABORT;
+					}
+					else
+						prog-=nnIdxs.size();	
 
 				}
 
@@ -2219,7 +2196,7 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 	//Step 4 in the  Process : Bulk erosion 
 	//====
 	//Check if we need the erosion step
-	if(needErosion)
+	if(needErosion && enableBulkLink)
 	{
 		//Update progress stuff
 		progress.step++;
@@ -2296,13 +2273,14 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 	}
 	//===
 
+	if(*Filter::wantAbort)
+		return FILTER_ERR_ABORT;
+
+	//update progress
 	progress.step++;
 	progress.filterProgress=0;
 	progress.stepName=TRANS("Re-Collate");
 
-	//update progress
-	if(*Filter::wantAbort)
-		return FILTER_ERR_ABORT;
 	clusteredCore.resize(allCoreClusters.size());
 	clusteredBulk.resize(allBulkClusters.size());
 
@@ -2332,6 +2310,7 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 		}
 	}
 
+	progress.filterProgress=100;
 
 	return 0;	
 }
@@ -2574,9 +2553,10 @@ void ClusterAnalysisFilter::createRangedIons(const std::vector<const FilterStrea
 	buildRangeEnabledMap(r,rangeEnabledMap);
 	ASSERT(rangeEnabledMap.size() == ionCoreEnabled.size());
 
-	bool needBulk = bulkLink > std::numeric_limits<float>::epsilon();
 
-	if(needBulk)
+	unsigned int numIonsRanged=0;
+
+	if(enableBulkLink)
 	{
 		for(size_t ui=0;ui<dataIn.size();ui++)
 		{
@@ -2603,6 +2583,7 @@ void ClusterAnalysisFilter::createRangedIons(const std::vector<const FilterStrea
 						}
 					}
 				}
+				numIonsRanged++;
 			}
 		
 		
@@ -2626,6 +2607,7 @@ void ClusterAnalysisFilter::createRangedIons(const std::vector<const FilterStrea
 						#pragma omp critical 
 						core.push_back(d->data[ui]);
 					}
+					numIonsRanged++;
 				}
 			}
 		}
@@ -2708,6 +2690,7 @@ PlotStreamData* ClusterAnalysisFilter::clusterSizeDistribution(const vector<vect
 
 bool ClusterAnalysisFilter::stripClusterBySize(vector<vector<IonHit> > &clusteredCore,
 						vector<vector<IonHit> > &clusteredBulk,
+							bool countBulk,
 							ProgressData &progress) const
 
 {
@@ -2725,7 +2708,10 @@ bool ClusterAnalysisFilter::stripClusterBySize(vector<vector<IonHit> > &clustere
 			ui--;
 			//Count both bulk and core, and operate on both.
 			size_t count;
-			count =clusteredCore[ui].size() + clusteredBulk[ui].size() ;
+			if(countBulk)
+				count =clusteredCore[ui].size() + clusteredBulk[ui].size() ;
+			else
+				count =clusteredCore[ui].size();
 
 			if(count < nMin || count > nMax)
 			{
