@@ -1,6 +1,6 @@
 /*
  *	dataLoad.h - Load data from various file sources
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #include "../filter.h"
 
+#include "../../common/basics.h"
 #include "../../common/translation.h"
 
 enum
@@ -57,8 +58,6 @@ class DataLoadFilter:public Filter
 		//!Type of file to open
 		unsigned int fileType;
 
-		//!Try our best to guess the file type?
-		bool guessType;
 
 
 		//!Whether to randomly sample dataset during load or not
@@ -68,7 +67,7 @@ class DataLoadFilter:public Filter
 		size_t maxIons;
 
 		//!Default ion colour vars
-		float r,g,b,a;
+		ColourRGBAf rgbaf;
 
 		//!Default ion size (view size)
 		float ionSize;
@@ -129,7 +128,7 @@ class DataLoadFilter:public Filter
 		//!Refresh object data
 		unsigned int refresh(const std::vector<const FilterStreamData *> &dataIn,
 				std::vector<const FilterStreamData *> &getOut, 
-				ProgressData &progress, bool (*callback)(bool));
+				ProgressData &progress);
 
 		void updatePosData();
 
@@ -142,7 +141,7 @@ class DataLoadFilter:public Filter
 		bool setProperty( unsigned int key, const std::string &value, bool &needUpdate);
 		
 		//!Get the human readable error string associated with a particular error code during refresh(...)
-		std::string getErrString(unsigned int code) const;
+		std::string getSpecificErrString(unsigned int code) const;
 
 		//!Dump state to output stream, using specified format
 		bool writeState(std::ostream &f,unsigned int format, 
@@ -164,7 +163,7 @@ class DataLoadFilter:public Filter
 		virtual unsigned int getRefreshUseMask() const; 
 	
 		//!Pos filter has state overrides	
-		virtual void getStateOverrides(std::vector<string> &overrides) const; 
+		virtual void getStateOverrides(std::vector<std::string> &overrides) const; 
 		
 		//!Set internal property value using a selection binding  (Disabled, this filter has no bindings)
 		void setPropFromBinding(const SelectionBinding &b)  ;
