@@ -1,6 +1,6 @@
 /*
  *	externalProgram.cpp - Call out external programs as a datasource/sink
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -21,15 +21,21 @@
 
 #include "../../wx/wxcommon.h"
 #include "backend/APT/APTFileIO.h"
+#include "backend/plot.h"
 
 #include <wx/filename.h>
 #include <wx/dir.h>
 
+using std::vector;
+using std::string;
+using std::pair;
+using std::make_pair;
 
 //!Error codes
 enum
 {
 	COMMANDLINE_FAIL=1,
+	SYSTEM_EXEC_FAIL,
 	SETWORKDIR_FAIL,
 	WRITEPOS_FAIL,
 	WRITEPLOT_FAIL,
@@ -39,6 +45,7 @@ enum
 	READPOS_FAIL,
 	SUBSTITUTE_FAIL,
 	COMMAND_FAIL, 
+	EXT_PROG_ERR_ENUM_END, 
 };
 
 //=== External program filter === 
@@ -59,7 +66,7 @@ Filter *ExternalProgramFilter::cloneUncached() const
 	p->alwaysCache=alwaysCache;
 	p->cleanInput=cleanInput;
 
-	//We are copying wether to cache or not,
+	//We are copying whether to cache or not,
 	//not the cache itself
 	p->cache=cache;
 	p->cacheOK=false;
@@ -207,26 +214,28 @@ size_t ExternalProgramFilter::substituteVariables(const std::string &commandStr,
 }
 
 unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStreamData *> &dataIn,
-	std::vector<const FilterStreamData *> &getOut, ProgressData &progress, bool (*callback)(bool))
+	std::vector<const FilterStreamData *> &getOut, ProgressData &progress)
 {
 	//use the cached copy if we have it.
 	if(cacheOK)
 	{
 		propagateCache(getOut);
-
+		progress.filterProgress=100;
 		return 0;
 	}
 
 	if(commandLine.empty())
+	{
+		progress.filterProgress=100;
 		return 0;
-
+	}
 	vector<string> ionOutputNames,plotOutputNames;
 
 	//Compute the bounding box of the incoming streams
 	string s;
 	wxString tempDir;
 	if(workingDir.size())
-		tempDir=(wxStr(workingDir) +wxT("/inputData"));
+		tempDir=((workingDir) +wxT("/inputData"));
 	else
 		tempDir=(wxT("inputData"));
 
@@ -243,8 +252,11 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 		if(!wxDirExists(tempDir) )	
 			return MAKEDIR_FAIL;
 
-	}
 	
+	}
+	progress.maxStep=3;
+	progress.step=1;
+	progress.stepName=TRANS("Collate Input");	
 	for(unsigned int ui=0;ui<dataIn.size() ;ui++)
 	{
 		switch(dataIn[ui]->getStreamType())
@@ -306,8 +318,10 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 	//Nothing to do.
 	if(plotOutputNames.empty() &&
 		ionOutputNames.empty())
+	{
+		progress.filterProgress=100;
 		return 0;
-
+	}
 	std::string substitutedCommand;
 	size_t errCode;
 	errCode=substituteVariables(commandLine,ionOutputNames,plotOutputNames,
@@ -320,7 +334,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 	if(workingDir.size())
 	{
 		//Set the working directory before launching
-		if(!wxSetWorkingDirectory(wxStr(workingDir)))
+		if(!wxSetWorkingDirectory((workingDir)))
 			return SETWORKDIR_FAIL;
 	}
 	else
@@ -329,9 +343,16 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 			return SETWORKDIR_FAIL;
 	}
 
-	bool result;
+	int result;
+	progress.step=2;
+	progress.stepName=TRANS("Execute");	
+
 	//Execute the program
-	result=wxShell(wxStr(substitutedCommand));
+	//TODO: IO redirection - especially under windows?
+	result=std::system(substitutedCommand.c_str());
+
+	if(result == -1)
+		return SYSTEM_EXEC_FAIL; 
 
 	if(cleanInput)
 	{
@@ -339,23 +360,20 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 		//delete the input files.
 		for(unsigned int ui=0;ui<ionOutputNames.size();ui++)
 		{
-			//try to delete the file
-			wxRemoveFile(wxStr(ionOutputNames[ui]));
+			//try to delete the file, if the command did not
+			// remove it
+			if(wxFileExists(ionOutputNames[ui]))
+				wxRemoveFile(ionOutputNames[ui]);
 
-			//call the update to be nice
-			(*callback)(false);
 		}
 		for(unsigned int ui=0;ui<plotOutputNames.size();ui++)
 		{
 			//try to delete the file
-			wxRemoveFile(wxStr(plotOutputNames[ui]));
-
-			//call the update to be nice
-			(*callback)(false);
+			wxRemoveFile((plotOutputNames[ui]));
 		}
 	}
 	wxSetWorkingDirectory(origDir);	
-	if(!result)
+	if(result)
 		return COMMAND_FAIL; 
 	
 	wxSetWorkingDirectory(origDir);	
@@ -363,10 +381,12 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 	wxDir *dir = new wxDir;
 	wxArrayString *a = new wxArrayString;
 	if(workingDir.size())
-		dir->GetAllFiles(wxStr(workingDir),a,wxT("*.pos"),wxDIR_FILES);
+		dir->GetAllFiles((workingDir),a,wxT("*.pos"),wxDIR_FILES);
 	else
 		dir->GetAllFiles(wxGetCwd(),a,wxT("*.pos"),wxDIR_FILES);
 
+	progress.step=3;
+	progress.stepName=TRANS("Collate output");	
 
 	//read the output files, which is assumed to be any "pos" file
 	//in the working dir
@@ -397,7 +417,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 			unsigned int index2[] = {
 					0, 1, 2, 3
 					};
-			if(GenericLoadFloatFile(4, 4, index2, d->data,sTmp.c_str(),dummy,dummyCallback))
+			if(GenericLoadFloatFile(4, 4, index2, d->data,sTmp.c_str(),dummy,*(Filter::wantAbort)))
 			{
 				delete d;
 				delete dir;
@@ -418,7 +438,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 
 	a->Clear();
 	if(workingDir.size())
-		dir->GetAllFiles(wxStr(workingDir),a,wxT("*.xy"),wxDIR_FILES);
+		dir->GetAllFiles((workingDir),a,wxT("*.xy"),wxDIR_FILES);
 	else
 		dir->GetAllFiles(wxGetCwd(),a,wxT("*.xy"),wxDIR_FILES);
 
@@ -478,7 +498,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 				d->a=1.0;
 				d->index=uj;
 				d->plotMode=PLOT_MODE_1D;
-				d->plotStyle=PLOT_TRACE_LINES;
+				d->plotStyle=PLOT_LINE_LINES;
 
 
 				//set the title to the filename (trim the .xy extension
@@ -529,6 +549,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 
 	delete dir;
 	delete a;
+	progress.filterProgress=100;
 
 	return 0;
 }
@@ -549,17 +570,14 @@ void ExternalProgramFilter::getProperties(FilterPropGroup &propertyList) const
 	
 	p.name=TRANS("Work Dir");
 	p.data= workingDir;
-	p.type=PROPERTY_TYPE_STRING;
+	p.type=PROPERTY_TYPE_DIR;
 	p.helpText=TRANS("Directory to run the command in");
 	p.key=EXTERNALPROGRAM_KEY_WORKDIR;		
 	propertyList.addProperty(p,curGroup);
 	
-
-	if(cleanInput)
-		tmpStr="1";
-	else
-		tmpStr="0";
-
+	propertyList.setGroupTitle(curGroup,TRANS("Command"));
+	curGroup++;
+	tmpStr=boolStrEnc(cleanInput);
 	p.name=TRANS("Cleanup input");
 	p.data=tmpStr;
 	p.type=PROPERTY_TYPE_BOOL;
@@ -567,11 +585,7 @@ void ExternalProgramFilter::getProperties(FilterPropGroup &propertyList) const
 	p.key=EXTERNALPROGRAM_KEY_CLEANUPINPUT;		
 	propertyList.addProperty(p,curGroup);
 	
-	if(alwaysCache)
-		tmpStr="1";
-	else
-		tmpStr="0";
-	
+	tmpStr=boolStrEnc(alwaysCache);
 	p.name=TRANS("Cache");
 	p.data=tmpStr;
 	p.type=PROPERTY_TYPE_BOOL;
@@ -579,6 +593,7 @@ void ExternalProgramFilter::getProperties(FilterPropGroup &propertyList) const
 	p.key=EXTERNALPROGRAM_KEY_ALWAYSCACHE;		
 	propertyList.addProperty(p,curGroup);
 
+	propertyList.setGroupTitle(curGroup,TRANS("Data"));
 }
 
 bool ExternalProgramFilter::setProperty(  unsigned int key,
@@ -589,12 +604,8 @@ bool ExternalProgramFilter::setProperty(  unsigned int key,
 	{
 		case EXTERNALPROGRAM_KEY_COMMAND:
 		{
-			if(commandLine!=value)
-			{
-				commandLine=value;
-				needUpdate=true;
-				clearCache();
-			}
+			if(!applyPropertyNow(commandLine,value,needUpdate))
+				return false;
 			break;
 		}
 		case EXTERNALPROGRAM_KEY_WORKDIR:
@@ -602,7 +613,7 @@ bool ExternalProgramFilter::setProperty(  unsigned int key,
 			if(workingDir!=value)
 			{
 				//Check the directory exists
-				if(!wxDirExists(wxStr(value)))
+				if(!wxDirExists((value)))
 					return false;
 
 				workingDir=value;
@@ -613,33 +624,14 @@ bool ExternalProgramFilter::setProperty(  unsigned int key,
 		}
 		case EXTERNALPROGRAM_KEY_ALWAYSCACHE:
 		{
-			string stripped=stripWhite(value);
-
-			if(!(stripped == "1"|| stripped == "0"))
+			if(!applyPropertyNow(alwaysCache,value,needUpdate))
 				return false;
-
-			if(stripped=="1")
-				alwaysCache=true;
-			else
-			{
-				alwaysCache=false;
-
-				//If we need to generate a cache, do so
-				//otherwise, trash it
-				clearCache();
-			}
-
-			needUpdate=true;
 			break;
 		}
 		case EXTERNALPROGRAM_KEY_CLEANUPINPUT:
 		{
-			string stripped=stripWhite(value);
-
-			if(!(stripped == "1"|| stripped == "0"))
+			if(!applyPropertyNow(cleanInput,value,needUpdate))
 				return false;
-			cleanInput=(stripped=="1");
-			needUpdate=true;
 			break;
 		}
 		default:
@@ -651,35 +643,24 @@ bool ExternalProgramFilter::setProperty(  unsigned int key,
 }
 
 
-std::string  ExternalProgramFilter::getErrString(unsigned int code) const
+std::string  ExternalProgramFilter::getSpecificErrString(unsigned int code) const
 {
-
-	switch(code)
-	{
-		case COMMANDLINE_FAIL:
-			return std::string(TRANS("Error processing command line"));
-		case SETWORKDIR_FAIL:
-			return std::string(TRANS("Unable to set working directory"));
-		case WRITEPOS_FAIL:
-			return std::string(TRANS("Error saving posfile result for external program"));
-		case WRITEPLOT_FAIL:
-			return std::string(TRANS("Error saving plot result for externalprogram"));
-		case MAKEDIR_FAIL:
-			return std::string(TRANS("Error creating temporary directory"));
-		case PLOTCOLUMNS_FAIL:
-			return std::string(TRANS("Detected unusable number of columns in plot"));
-		case READPLOT_FAIL:
-			return std::string(TRANS("Unable to parse plot result from external program"));
-		case READPOS_FAIL:
-			return std::string(TRANS("Unable to load ions from external program")); 
-		case SUBSTITUTE_FAIL:
-			return std::string(TRANS("Unable to perform commandline substitution"));
-		case COMMAND_FAIL: 
-			return std::string(TRANS("Error executing external program"));
-		default:
-			//Currently the only error is aborting
-			return std::string("Bug: write me (externalProgramfilter).");
-	}
+	const char *errStrs[] = 	{ "",
+			"Error processing command line",
+			"Unable to launch external program",
+			"Unable to set working directory",
+			"Error saving posfile result for external program",
+			"Error saving plot result for externalprogram",
+			"Error creating temporary directory",
+			"Detected unusable number of columns in plot",
+			"Unable to parse plot result from external program",
+			"Unable to load ions from external program", 
+			"Unable to perform commandline substitution",
+			"Error executing external program, returned nonzero" };
+	
+	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(errStrs) == EXT_PROG_ERR_ENUM_END);
+	ASSERT(code < EXT_PROG_ERR_ENUM_END);
+	return errStrs[code];
 }
 
 void ExternalProgramFilter::setPropFromBinding(const SelectionBinding &b)
@@ -749,22 +730,14 @@ bool ExternalProgramFilter::readState(xmlNodePtr &nodePtr, const std::string &st
 	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"alwayscache","value"))
 		return false;
 
-	if(tmpStr == "1") 
-		alwaysCache=true;
-	else if(tmpStr== "0")
-		alwaysCache=false;
-	else
+	if(!boolStrDec(tmpStr,alwaysCache))
 		return false;
 
 	//check readable 
 	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"cleaninput","value"))
 		return false;
 
-	if(tmpStr == "1") 
-		cleanInput=true;
-	else if(tmpStr== "0")
-		cleanInput=false;
-	else
+	if(!boolStrDec(tmpStr,cleanInput))
 		return false;
 
 	return true;
@@ -790,6 +763,9 @@ unsigned int ExternalProgramFilter::getRefreshUseMask() const
 #ifdef DEBUG
 #include <memory>
 
+using std::auto_ptr;
+using std::ifstream;
+
 bool echoTest()
 {
 	int errCode;
@@ -818,7 +794,7 @@ bool echoTest()
 	//Simulate some data to send to the filter
 	vector<const FilterStreamData*> streamIn,streamOut;
 	ProgressData p;
-	f->refresh(streamIn,streamOut,p,dummyCallback);
+	f->refresh(streamIn,streamOut,p);
 
 
 	s=stlStr(tmpFilename);
@@ -870,12 +846,19 @@ bool posTest()
 #else
 	tmpDir=tmpDir + wxT("/3Depict/");
 #endif
+	if(wxDirExists(tmpDir))
+	{
+		wxFileName dirFile(tmpDir);
+		dirFile.Rmdir( wxPATH_RMDIR_RECURSIVE);
+	}
+
+		
 	wxMkdir(tmpDir);
 
-	tmpFilename=wxFileName::CreateTempFileName(tmpDir+ wxT("unittest-"));
-	wxRemoveFile(tmpFilename);
-	tmpFilename+=wxT(".pos");
-	s ="mv \%i " + stlStr(tmpFilename);
+	std::string randName;
+	genRandomFilename(randName);
+	tmpFilename = tmpDir + "/" + randName + ".pos";
+	s ="mv -f \%i " + tmpFilename;
 
 	ASSERT(tmpFilename.size());
 	
@@ -885,7 +868,7 @@ bool posTest()
 	vector<const FilterStreamData*> streamIn,streamOut;
 	streamIn.push_back(someData.get());
 	ProgressData p;
-	TEST(!f->refresh(streamIn,streamOut,p,dummyCallback),"refresh error code");
+	TEST(!f->refresh(streamIn,streamOut,p),"refresh error code");
 
 	//Should have exactly one stream, which is an ion stream
 	TEST(streamOut.size() == 1,"stream count");
@@ -943,13 +926,14 @@ bool ExternalProgramFilter::runUnitTests()
 {
 	if(!echoTest())
 		return false;
-	
+
+#ifndef __APPLE__
 	if(!posTest())
 		return false;
 
 	if(!substituteTest())
 		return false;
-
+#endif
 	return true;
 }
 
