@@ -1,6 +1,6 @@
 /*
  *	ionColour.h - Filter to create coloured batches of ions based upon value
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -44,6 +44,8 @@ class IonColourFilter: public Filter
 		//!Should we display the colour bar?
 		bool showColourBar;
 
+		//Transparency value
+		float alpha;
 	public:
 		IonColourFilter();
 		//!Duplicate filter contents, excluding cache.
@@ -55,7 +57,7 @@ class IonColourFilter: public Filter
 		//update filter
 		unsigned int refresh(const std::vector<const FilterStreamData *> &dataIn,
 				std::vector<const FilterStreamData *> &getOut, 
-				ProgressData &progress, bool (*callback)(bool));
+				ProgressData &progress);
 
 		//!return string naming the human readable type of this class
 		virtual std::string typeString() const { return std::string(TRANS("Spectral Colour"));}
@@ -67,7 +69,7 @@ class IonColourFilter: public Filter
 		//!Set the properties for the nth filter
 		bool setProperty( unsigned int key, const std::string &value, bool &needUpdate);
 		//!Get the human readable error string associated with a particular error code during refresh(...)
-		std::string getErrString(unsigned int code) const;
+		std::string getSpecificErrString(unsigned int code) const;
 
 		//!Dump state to output stream, using specified format
 		bool writeState(std::ostream &f,unsigned int format, 
