@@ -116,6 +116,11 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 		return 0;
 	}
 
+	progress.filterProgress=0;
+	progress.stepName=TRANS("Ranging");
+	progress.step=1;
+	progress.maxStep=1;	
+
 
 	ASSERT(enabledRanges.size() == rng.getNumRanges());
 	ASSERT(enabledIons.size() == rng.getNumIons());
@@ -148,11 +153,6 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 		sameSize=true;
 
 
-		progress.step=1;
-		progress.filterProgress=0;
-		progress.stepName=TRANS("Pre-Allocate");
-		progress.maxStep=2;	
-
 		vector<size_t> dSizes;
 		dSizes.resize(d.size(),0);
 		size_t totalSize=numElements(dataIn);
@@ -249,7 +249,12 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 						}
 
 						if(spin)
+						{
+#ifdef _OPENMP
+							delete[] dSizeArr;
+#endif
 							return RANGEFILE_ABORT_FAIL;
+						}
 #ifdef _OPENMP
 						//Merge the arrays back together
 						for(unsigned int uk=0;uk<nT;uk++)
@@ -270,7 +275,7 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 		{
 			//slightly over-allocate to allow for any variance
 			for(size_t ui=0;ui<d.size();ui++)
-				d[ui]->data.reserve(dSizes[ui]*1.f*RANGE_ALLOC_STEP+10);
+				d[ui]->data.reserve(dSizes[ui]*1.05f*RANGE_ALLOC_STEP+10);
 		}
 		catch(std::bad_alloc)
 		{
@@ -282,12 +287,6 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 		dSizes.clear();
 		//===================================
 
-		//Update progress info
-		progress.step=2;
-		progress.filterProgress=0;
-		progress.stepName=TRANS("Range");
-
-
 		
 
 		//Step 2: Go through each data stream, if it is an ion stream, range it.
@@ -507,6 +506,9 @@ unsigned int RangeFileFilter::refresh(const std::vector<const FilterStreamData *
 	getOut.push_back(rngData);
 		
 	cacheOK=cache;
+
+	progress.filterProgress=100;
+
 	return 0;
 }
 
