@@ -1,6 +1,6 @@
 /*
  *	voxelise.h - Compute 3D binning (voxelisation) of point clouds
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -18,6 +18,9 @@
 #ifndef VOXELISE_H
 #define VOXELISE_H
 #include "../filter.h"
+
+#include "common/voxels.h"
+
 #include "../../common/translation.h"
 
 //!Filter that does voxelisation for various primitives (copied from CompositionFilter)
@@ -48,7 +51,7 @@ private:
 	//This is filter's enabled ranges
 	RangeStreamData *rsdIncoming;
 	
-	float r,g,b,a;
+	ColourRGBAf rgba;
 
 	//!Filter mode to apply to data before output
 	unsigned int filterMode;
@@ -56,8 +59,8 @@ private:
 	//!How do we treat boundaries when applying filters
 	unsigned int filterBoundaryMode;
 
-	//!Filter size
-	unsigned int filterBins;
+	//!Filter size, in units of gaussDevs 
+	float filterRatio;
 
 	//!Gaussian filter standard deviation
 	float gaussDev;
@@ -84,8 +87,6 @@ private:
 
 	//Interpolation mode to use when slicing	
 	size_t sliceInterpolate;
-	//Interpolation boundary handling mode
-	size_t sliceBoundMode;
 	//Axis that is normal to the slice 0,1,2 => x,y,z
 	size_t sliceAxis;
 	//Fractional offset from lower bound of data cube [0,1]
@@ -116,7 +117,7 @@ public:
 	//!update filter
 	unsigned int refresh(const std::vector<const FilterStreamData *> &dataIn,
 						 std::vector<const FilterStreamData *> &getOut, 
-						 ProgressData &progress, bool (*callback)(bool));
+						 ProgressData &progress);
 	
 	virtual std::string typeString() const { return std::string(TRANS("Voxelisation"));};
 
@@ -136,7 +137,7 @@ public:
 	bool setProperty(unsigned int key, 
 					 const std::string &value, bool &needUpdate);
 	//!Get the human readable error string associated with a particular error code during refresh(...)
-	std::string getErrString(unsigned int code) const;
+	std::string getSpecificErrString(unsigned int code) const;
 	
 	//!Dump state to output stream, using specified format
 	bool writeState(std::ostream &f,unsigned int format, 
