@@ -1,6 +1,6 @@
 /*
  * 	filtertree.h - Filter tree topology and data propagation handling
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -61,9 +61,15 @@ class FilterTreeAnalyse
 		// are being used with sampling.
 		void spatialSampling(const FilterTree &f);
 
+		//check to see if there is a filter who is biasing composition
 		void compositionAltered(const FilterTree &f);
 
+		//check to see if there is a filter that needs a particular parent
 		void checkRequiredParent(const FilterTree &f);
+		
+		//check to see if there is a filter that needs unranged data to work,
+		// but does not have it 
+		void checkUnrangedData(const FilterTree &f);
 	public:
 		void analyse(const FilterTree &f);
 
