@@ -285,7 +285,8 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	return true;
 }
 
-bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errStream ) 
+
+bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostream &errStream)
 {
 	if(doMerge)
 	{
@@ -561,6 +562,7 @@ bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errS
 				errStream<< TRANS("Unable to interpret property \"value\"  for \"cameras->active\" node.") << endl;
 				throw 1;
 			}
+			xmlFree(xmlString);
 
 		
 			//Spin through the list of each camera	
@@ -590,20 +592,34 @@ bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errS
 				}
 
 				ASSERT(thisCam);
-				newCameraVec.push_back(thisCam);	
+
+				//Discard any cameras that are non-unique There is a bug in some of the writer functions,
+				// so we can receive invalid data. We have to enforce validity
+				bool haveCameraAlready;
+				haveCameraAlready=false;
+				for(unsigned int ui=0; ui<newCameraVec.size() ; ui++)
+				{
+					if(thisCam->getUserString() == newCameraVec[ui]->getUserString())
+					{
+						haveCameraAlready=true;
+#ifdef DEBUG
+						cerr << "Found duplicate camera, ignoring" << endl;
+	#endif
+						break;
+					} 
+				}
+				if(!haveCameraAlready)
+					newCameraVec.push_back(thisCam);
+				else
+				{
+					delete thisCam;
+					thisCam=0;
+				}	
 			}
 
 
 		}
 
-		
-		//Enforce active cam value validity.
-		if(newCameraVec.empty())	
-			newCameraVec.push_back(new CameraLookAt);
-
-		if(newCameraVec.size() < activeCamera)
-			activeCamera=0;
-
 		//Now the cameras are loaded into a temporary vector. We will 
 		// copy them into the scene soon
 
@@ -812,11 +828,10 @@ bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errS
 	//Wipe the existing cameras, and then put the new cameras in place
 	savedCameras.clear();
 	
-	//Set a default camera as needed. We don't need to track its unique ID, as this is
-	//"invisible" to the UI
+	//Set a default camera as needed. 
 	Camera *c=new CameraLookAt();
 	savedCameras.push_back(c);
-	activeCamera=0;
+	
 	bool defaultSet = false;
 	//spin through
 	for(unsigned int ui=0;ui<newCameraVec.size();ui++)
@@ -827,11 +842,11 @@ bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errS
 		// set it directly. Otherwise, its a user camera.
 
 		//if there are multiple without a string, only use the first
-		if(newCameraVec[ui]->getUserString().size() && !defaultSet)
+		if(newCameraVec[ui]->getUserString().size())
 		{
 			savedCameras.push_back(newCameraVec[ui]);
 		}
-		else
+		else if (!defaultSet)
 		{
 			ASSERT(savedCameras.size());
 			delete savedCameras[0];
@@ -874,10 +889,24 @@ bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errS
 	// state is overwritten
 	setStateModifyLevel(STATE_MODIFIED_NONE);
 
+#ifdef DEBUG
+	checkSane();
+#endif
 	//Perform sanitisation on results
 	return true;
 }
 
+bool AnalysisState::load(const char *cpFilename, bool doMerge,std::ostream &errStream ) 
+{
+	AnalysisState otherState;
+	if(!otherState.loadInternal(cpFilename,doMerge,errStream))
+		return false;
+
+	*this=otherState;
+
+	return true;
+}
+
 void AnalysisState::merge(const AnalysisState &otherState)
 {
 
@@ -910,7 +939,8 @@ void AnalysisState::merge(const AnalysisState &otherState)
 	//wipe treestate's undo/redo trees, as we can no longer rely on them
 	treeState.clearUndoRedoStacks();	
 
-	treeState.addFilterTree(f,0);
+	if(f.size())
+		treeState.addFilterTree(f,true);
 	
 
 	const vector<Camera *> &newCameraVec = otherState.savedCameras;	
@@ -977,6 +1007,7 @@ void AnalysisState::removeCam(size_t offset)
 	setStateModifyLevel(STATE_MODIFIED_ANCILLARY);
 
 	ASSERT(offset < savedCameras.size());
+	delete savedCameras[offset];
 	savedCameras.erase(savedCameras.begin()+offset);
 	if(activeCamera >=savedCameras.size())
 		activeCamera=0;
@@ -990,6 +1021,8 @@ void AnalysisState::addCamByClone(const Camera *c)
 
 void AnalysisState::addCam(const std::string &camName, bool makeActive)
 {
+	//Disallow unnamed cameras
+	ASSERT(camName.size());
 	//Duplicate the current camera, and give it a new name
 	Camera *c=getCam(getActiveCam())->clone();
 	c->setUserString(camName);
@@ -1161,7 +1194,18 @@ std::string AnalysisState::getStashName(size_t offset) const
 	return  stashedTrees[offset].first;
 }
 
+#ifdef DEBUG
+void AnalysisState::checkSane() const
+{
+	ASSERT(activeCamera < savedCameras.size());
 
+	ASSERT(rBack >=0.0f && rBack <=1.0f 
+		&& gBack <= 1.0f && gBack >=0.0f &&
+		bBack >=0.0f && bBack <=1.0f);
+
+	
+}
+#endif
 
 void AnalysisState::eraseStash(size_t offset)
 {
@@ -1170,6 +1214,22 @@ void AnalysisState::eraseStash(size_t offset)
 	stashedTrees.erase(stashedTrees.begin() + offset);
 }
 
+void AnalysisState::eraseStashes(std::vector<size_t> &offsets)
+{
+	std::sort(offsets.begin(),offsets.end());
+	ASSERT(std::unique(offsets.begin(),offsets.end()) == offsets.end());
+
+
+
+	setStateModifyLevel(STATE_MODIFIED_ANCILLARY);
+	for(unsigned int ui=offsets.size();ui>0;)
+	{
+		ui--;
+		
+		stashedTrees.erase(stashedTrees.begin() + offsets[ui]);
+	}
+}
+		
 bool AnalysisState::hasStateOverrides() const
 {
 	if(treeState.hasStateOverrides())
@@ -1189,7 +1249,7 @@ void TreeState::operator=(const TreeState &oth)
 #ifdef DEBUG
 	//Should not be refreshing
 	wxMutexLocker lock(amRefreshing);
-	ASSERT(!lock.IsOk());
+	ASSERT(lock.IsOk());
 #endif
 	filterTree=oth.filterTree;	
 	
@@ -1198,7 +1258,6 @@ void TreeState::operator=(const TreeState &oth)
 	redoFilterStack=oth.redoFilterStack;
 	undoFilterStack=oth.undoFilterStack;
 	
-	fta=oth.fta;
 	selectionDevices=oth.selectionDevices;
 	pendingUpdates=oth.pendingUpdates;
 	
@@ -1237,12 +1296,15 @@ void TreeState::addFilter(Filter *f, bool isBase,size_t parentId)
 
 void TreeState::addFilterTree(FilterTree &f, bool isBase,size_t parentId)
 { 
-	ASSERT(!(isBase && parentId==(unsigned int)-1));
+	ASSERT(!(isBase && parentId==(size_t)-1));
 
 	if(isBase)
 		filterTree.addFilterTree(f,0);
 	else
+	{
+		ASSERT(filterMap.size());
 		filterTree.addFilterTree(f,filterMap[parentId]);
+	}
 
 	//FIXME: This technically does not need to be cleared. We can
 	// tweak the filter map to remain valid. It is the caller's problem
@@ -1549,6 +1611,17 @@ bool TreeState::hasUpdates() const
 {
 	return pendingUpdates;
 }
+bool TreeState::hasMonitorUpdates() const
+{
+	for(tree<Filter *>::iterator it=filterTree.depthBegin(); 
+			it!=filterTree.depthEnd();++it)
+	{
+		if((*it)->monitorNeedsRefresh())
+			return true;
+	}
+
+	return false;
+}
 
 
 
