@@ -97,6 +97,9 @@ class TreeState
 
 		//!Returns true if the filter tree has updates that need to be processed
 		bool hasUpdates() const; 
+		
+		//!Returns true if the filter tree has updates via a filter monitor 
+		bool hasMonitorUpdates() const; 
 
 		//Obtain a clone of the active filter tree
 		void cloneFilterTree(FilterTree &f) const {f=filterTree;};
@@ -276,6 +279,14 @@ class AnalysisState
 		//Clear the camera data vector
 		void clearCams();
 
+		//Actual load function for loading internal state
+		// this is used by ::load to mitigate actual "state" 
+		// class instance modifications on failure
+		bool loadInternal(const char *cpFilename,  bool merge,
+				std::ostream &errStream);
+#ifdef DEBUG
+		void checkSane() const;
+#endif
 	public:
 
 		TreeState treeState;
@@ -301,7 +312,9 @@ class AnalysisState
 				std::ostream &errStream);
 
 		//save an XML-ised representation of the analysis sate
-		//	- mapping provides the on-disk to local name mapping to use when saving
+		//	- Provides the on-disk to local name
+		//      mapping to use when saving. This needs to be copied by
+		//     the caller into the same dir as the XML file to be usable
 		// 	- write package says if state should attempt to ensure that output
 		// 		state is fully self-contained, and locally referenced
 		bool save(const char *cpFilename, std::map<std::string,std::string> &fileMapping,
@@ -339,7 +352,7 @@ class AnalysisState
 		void setCameraByClone(const Camera *c, unsigned int offset) ;
 
 		//Obtain the ID of the active camera
-		size_t getActiveCam() const  { return activeCamera;};
+		size_t getActiveCam() const  { ASSERT(activeCamera < savedCameras.size()) ; return activeCamera;};
 
 		//Set
 		void setActiveCam(size_t offset) {ASSERT(offset < savedCameras.size()); activeCamera=offset; };
@@ -417,8 +430,11 @@ class AnalysisState
 
 		//!Insert  the given stash into the tree as a child of the given parent filter
 		void addStashedToFilters(const Filter *parentFilter, unsigned int stashOffset);
-		//Remove the stash at the specified offset
+		//Remove the stash at the specified offset. Numbers will
+		// be reset, so previous offsets will no longer be valid
 		void eraseStash(size_t offset);
+		//Remove the given stashew at the specified offsets
+		void eraseStashes(std::vector<size_t> &offset);
 
 		//Return the number of stash elements
 		size_t getStashCount()  const { return stashedTrees.size();}
