@@ -1,6 +1,6 @@
 /*
  * common/assertion.h  - Program assertion header
- * Copyright (C) 2013  D Haley
+ * Copyright (C) 2015  D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include "assertion.h"
 #include <iostream>
 
+#ifdef DEBUG
 void userAskAssert(const char * const filename, const unsigned int lineNumber) 
 {
 
@@ -44,3 +45,37 @@ void userAskAssert(const char * const filename, const unsigned int lineNumber)
 	if(y == 'a')
 		skipAll=true;
 }
+
+//DEBUG NaN and INF
+#ifdef __linux__
+	#ifdef DEBUG
+	#include <fenv.h>
+	void trapfpe (bool doTrap) 
+	{
+		if(doTrap)
+		{
+			feenableexcept(FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW);
+		}
+		else 
+		{
+			fedisableexcept((FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW));
+		}
+	}
+
+	bool getTrapfpe() 
+	{ 
+		return fegetexcept() & (FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW);
+	}
+	#endif
+#else
+	void trapfpe(bool doTrap)
+	{
+	}
+
+	bool getTrapfpe() 
+	{
+		return false;
+	}
+#endif
+
+#endif
