@@ -1,6 +1,6 @@
 /*
  * common/translation.h  - Program gettext translation macros
- * Copyright (C) 2013  D Haley
+ * Copyright (C) 2015  D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,9 +32,4 @@
 //!Gettext null-translation macro (mark for translation, but do nothing)
 #define NTRANS(x) (x)
 
-//!Wx friendly gettext translation macro
-#define wxTRANS(x) (wxString(gettext(x),*wxConvCurrent))
-
-#define wxNTRANS(x) wxT(x)
-
 #endif
