@@ -93,6 +93,7 @@ enum
 	DRAW_TYPE_CYLINDER,
 	DRAW_TYPE_DISPLAYLIST,
 	DRAW_TYPE_GLTEXT,
+	DRAW_TYPE_2D_CIRCLE,
 	DRAW_TYPE_RECTPRISM,
 	DRAW_TYPE_COLOURBAR,
 	DRAW_TYPE_TEXTUREDOVERLAY,
@@ -196,7 +197,7 @@ class DrawableObj
 
 		//!Set the active state of the object
 		void setActive(bool active);
-		//!Pure virtual funciton - draw the object
+		//!Pure virtual function - draw the object
 		virtual void draw() const =0;
 
 		//!Set if user can interact with object, needed for opengl hit testing
@@ -531,6 +532,8 @@ class DrawSphere : public DrawableObj
 		//! Destructor
 		virtual ~DrawSphere();
 
+		virtual DrawableObj *clone() const;
+
 		virtual unsigned int getType() const {return DRAW_TYPE_SPHERE;};	
 		//!Sets the location of the sphere's origin
 		void setOrigin(const Point3D &p);
@@ -899,6 +902,7 @@ class DrawColourBarOverlay : public DrawableOverlay
 		DrawColourBarOverlay(const DrawColourBarOverlay &o);
 		~DrawColourBarOverlay(){delete font;};
 		
+		virtual DrawableObj *clone() const; 
 
 		virtual unsigned int getType() const {return DRAW_TYPE_COLOURBAR;}
 
@@ -1030,7 +1034,6 @@ class DrawProgressCircleOverlay : public DrawAnimatedOverlay
 class DrawPointLegendOverlay : public DrawableOverlay
 {
 	private:
-	static DrawTexturedQuad dQuad;
 	static bool quadSet;
 
 	FTFont *font;
@@ -1194,6 +1197,7 @@ class DrawAxis : public DrawableObj
 		Point3D position;
 		//!size
 		float size;
+
 	public:
 		DrawAxis();
 		~DrawAxis();
@@ -1211,5 +1215,41 @@ class DrawAxis : public DrawableObj
 		void setPosition(const Point3D &p);
 
 		void getBoundingBox(BoundCube &b) const;
+
 };
+
+
+//Draw a 2D filled circle
+class Draw2DCircle : public DrawableObj
+{
+	private:
+		float centre[2];
+		float angularStep;
+		float radius; 
+
+		//Circle colour
+		float r,g,b;
+
+		//Should the circle be drawn as an outline, or as a filled object
+		bool filled;
+	public:
+		Draw2DCircle();
+		
+		void result() const; 
+		//Obtain the type mask for this drawable
+		virtual unsigned int getType() const;	
+		virtual DrawableObj *clone() const; 
+		virtual void getBoundingBox(BoundCube &b) const;
+
+		virtual void draw() const;
+
+		void setCentre(float fx,float fy) { centre[0] = fx; centre[1]= fy;};
+		void setRadius(float r) { radius=r;}
+		//Angular step in radiians
+		void setAngularStep(float da) { angularStep = da;};
+	
+		void setColour(float rP, float gP, float bP) { r=rP;g=gP;b=bP;} ;
+			
+};
+
 #endif
