@@ -32,7 +32,7 @@
 #define glError() { \
 		GLenum err = glGetError(); \
 		while (err != GL_NO_ERROR) { \
-					fprintf(stderr, "glError: %s caught at %s:%u\n", (char *)gluErrorString(err), __FILE__, __LINE__); \
+					fprintf(stderr, "glError: %s caught at %s:%u\n", (char *)gluErrorString(err), __FILE__, (unsigned int)__LINE__); \
 					err = glGetError(); \
 				} \
 		}
