@@ -1,6 +1,6 @@
 /*
  * isoSurface.h  - Marching cubes implementation 
- * Copyright (C) 2013  D Haley
+ * Copyright (C) 2015  D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,5 +45,8 @@ struct TriangleWithIndexedVertices
 void marchingCubes(const Voxels<float> &v,float isoValue, 
 		std::vector<TriangleWithVertexNorm> &tVec);
 
+#ifdef DEBUG
+bool testIsoSurface();
+#endif
 
 #endif
