@@ -1,6 +1,6 @@
 /*
  *	scene.cpp  - OpenGL 3D static scene implementation
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "./backend/filter.h"
 
 using std::vector;
+using std::string;
 
 
 //
@@ -38,6 +39,7 @@ unsigned int ANIMATE_PROGRESS_NUMFRAMES=3;
 Scene::Scene() : tempCam(0), cameraSet(true), outWinAspect(1.0f)
 {
 	glewInited=false;
+	visControl=0;
 
 	lastHovered=lastSelected=(unsigned int)(-1);
 	lockInteract=false;
@@ -47,7 +49,6 @@ Scene::Scene() : tempCam(0), cameraSet(true), outWinAspect(1.0f)
 	useEffects=false;
 	showAxis=true;
 	attemptedLoadProgressAnim=false;
-	showProgressAnimation=false;
 	witholdCamUpdate=false;
 
 	//default to black
@@ -60,7 +61,6 @@ Scene::Scene() : tempCam(0), cameraSet(true), outWinAspect(1.0f)
 	lightPosition[2]= 1.0;
 	lightPosition[3]=0.0;
 
-
 	DrawableObj::setTexPool(new TexturePool);
 
 }
@@ -90,6 +90,8 @@ unsigned int Scene::initDraw()
 		glewInited=true;
 	}
 #endif
+
+
 	glClearColor( rBack, gBack, bBack,1.0f );
 	glClear(GL_COLOR_BUFFER_BIT |GL_DEPTH_BUFFER_BIT);
 
@@ -158,7 +160,17 @@ unsigned int Scene::initDraw()
 			animFiles[ui]=animFilename;
 		}
 
+
 		progressAnimTex.setTexture(animFiles);
+		//Cycle every this many seconds
+		progressAnimTex.setRepeatTime(6.0f);
+		//Ramp opacity for this long (seconds)
+		progressAnimTex.setFadeInTime(2.0f);
+		//Don't show the animation until this many sceonds
+		progressAnimTex.setShowDelayTime(1.5f);
+		
+		progressCircle.setFadeInTime(1.5f);
+		progressCircle.setShowDelayTime(1.0f);
 
 		updateProgressOverlay();
 	}
@@ -177,6 +189,23 @@ unsigned int Scene::initDraw()
 	return passes;
 }
 
+bool Scene::hasOverlays() const
+{
+	for(unsigned int ui=0;ui<objects.size();ui++)
+	{
+		if(objects[ui]->isOverlay())
+			return true;
+	}
+	
+	for(unsigned int ui=0;ui<refObjects.size();ui++)
+	{
+		if(refObjects[ui]->isOverlay())
+			return true;
+	}
+
+	return false;
+}
+
 void Scene::updateCam(const Camera *camToUse, bool useIdent=true) const
 {
 	Point3D lightNormal;
@@ -189,19 +218,20 @@ void Scene::updateCam(const Camera *camToUse, bool useIdent=true) const
 
 void Scene::updateProgressOverlay()
 {
-	progressAnimTex.setPos(0.9*winX,0.9*winY);
+	const float xPos= 0.85*winX;
+	const float yPos=0.85*winY;
+
+	progressAnimTex.setPosition(xPos,yPos);
 	progressAnimTex.setSize(0.1*winX);
-	//Cycle every this many seconds
-	progressAnimTex.setRepeatTime(6.0f);
-	//Ramp opacity for this long (seconds)
-	progressAnimTex.setFadeInTime(1.0f);
-	//Don't show the animation until this many sceonds
-	progressAnimTex.setShowDelayTime(1.0f);
+	//Draw the progress animation bar
+	progressCircle.setPosition(xPos,yPos);
+	progressCircle.setSize(0.15*winX);
 }
 
 void Scene::draw(bool noUpdateCam) 
 {
-
+	glError();
+	ASSERT(visControl);
 	glPushMatrix();
 
 	Camera *camToUse;
@@ -211,7 +241,7 @@ void Scene::draw(bool noUpdateCam)
 		camToUse=activeCam;
 
 	//Inform text about current camera, 
-	// so it can eg billboard if needed
+	// so it can e.g. billboard if needed
 	DrawableObj::setCurCamera(camToUse);
 	DrawableObj::setWindowSize(winX,winY);
 	DrawableObj::setBackgroundColour(rBack,gBack,bBack);
@@ -294,15 +324,21 @@ void Scene::draw(bool noUpdateCam)
 
 
 	glPopMatrix();
-		
-	//Now draw 2D overlays
-	if(!lockInteract&& lastHovered != (unsigned int)(-1) )
-		drawHoverOverlay();
-	drawOverlays();
+	
+	//Only draw 2D components if we
+	// are using normal camera	
+	if(!noUpdateCam)
+	{
+		//Now draw 2D overlays
+		if(!lockInteract&& lastHovered != (unsigned int)(-1) )
+			drawHoverOverlay();
 
-	//Draw progress, if needed
-	drawProgressAnim();
+		drawOverlays(noUpdateCam);
 
+		//Draw progress, if needed
+		drawProgressAnim();
+	}
+	glError();
 }
 
 void Scene::drawObjectVector(const vector<const DrawableObj*> &drawObjs, bool &lightsOn, bool drawOpaques) const
@@ -351,50 +387,84 @@ void Scene::drawObjectVector(const vector<const DrawableObj*> &drawObjs, bool &l
 
 		}
 		
+
+
+#ifdef DEBUG
+		//Ensure that the gl matrix sizes are correctly restored
+		int curDepth[3];
+		int oldMatMode;
+		curDepth[0] = glCurStackDepth(GL_MODELVIEW_STACK_DEPTH);		
+		curDepth[1] = glCurStackDepth(GL_PROJECTION_STACK_DEPTH);		
+		curDepth[2] = glCurStackDepth(GL_TEXTURE_STACK_DEPTH);		
+		glGetIntegerv( GL_MATRIX_MODE, &oldMatMode);
+#endif
 		drawObjs[ui]->draw();
+
+#ifdef DEBUG
+		ASSERT(curDepth[0] == glCurStackDepth(GL_MODELVIEW_STACK_DEPTH));	
+		ASSERT(curDepth[1] == glCurStackDepth(GL_PROJECTION_STACK_DEPTH));	
+		ASSERT(curDepth[2] == glCurStackDepth(GL_TEXTURE_STACK_DEPTH));		
+		ASSERT(curDepth[0] && curDepth[1] && curDepth[2]);
+		int newMatMode;
+		glGetIntegerv( GL_MATRIX_MODE, &newMatMode);
+		ASSERT(oldMatMode == newMatMode);
+#endif
 	}
 }
 
-void Scene::drawOverlays() const
+void Scene::drawOverlays(bool noUpdateCam) const
 {
 
 	//Custom projection matrix
-	glMatrixMode(GL_PROJECTION);
-	glPushMatrix();
-	glLoadIdentity();
-
 	glDisable(GL_LIGHTING);
-	//Set the opengl camera state back into modelview mode
-	gluOrtho2D(0, outWinAspect, 1.0, 0);
-
-
-
-	glMatrixMode(GL_MODELVIEW);
-	glPushMatrix();
-	glLoadIdentity();
-
 	glDisable(GL_DEPTH_TEST);
+	//Set the opengl camera state back into modelview mode
+	if(!noUpdateCam)
+	{
+		//clear projection and modelview matrices
+		glMatrixMode(GL_PROJECTION);
+		glPushMatrix();
+		glLoadIdentity();
+		gluOrtho2D(0, outWinAspect, 1.0, 0);
+
+		glMatrixMode(GL_MODELVIEW);
+		glPushMatrix();
+		glLoadIdentity();
+	}
+
 
 
 	for(unsigned int ui=0;ui<refObjects.size();ui++)
 	{
 		if(refObjects[ui]->isOverlay())
+		{
 			refObjects[ui]->draw();
+		}
 	}
 	
 	for(unsigned int ui=0;ui<objects.size();ui++)
 	{
 		if(objects[ui]->isOverlay())
+		{
 			objects[ui]->draw();
+		}
 	}
 	
 
-	glEnable(GL_DEPTH_TEST);
-	glPopMatrix();
-	glMatrixMode(GL_PROJECTION);
-	glPopMatrix();
+	if(!noUpdateCam)
+	{
+		//op our modelview matrix
+		glPopMatrix();
+		
+		//ppop projection atrix
+		glMatrixMode(GL_PROJECTION);
+		glPopMatrix();
+		//return to modelview mode
+		glMatrixMode(GL_MODELVIEW);
+	}
 
-	glMatrixMode(GL_MODELVIEW);
+	glEnable(GL_DEPTH_TEST);
+	glEnable(GL_LIGHTING);
 }
 
 void Scene::drawHoverOverlay()
@@ -411,6 +481,8 @@ void Scene::drawHoverOverlay()
 	glAlphaFunc(GL_GREATER,0.01f);
 	
 	vector<const SelectionBinding *> binder;
+	//!Devices for interactive object properties
+	const std::vector<SelectionDevice *> &selectionDevices = visControl->getSelectionDevices();
 	for(unsigned int uj=0;uj<selectionDevices.size();uj++)
 	{
 		if(selectionDevices[uj]->getAvailBindings(objects[lastHovered],binder))
@@ -504,14 +576,14 @@ void Scene::drawHoverOverlay()
 				if(foundKeyTex)
 				{
 					//Make room for keyTex
-					binderIcons.setPos((0.93+SPACING)*winX,ICON_SIZE*winY*(1+(float)iconNum));
-					keyIcons.setPos(0.93*winX,ICON_SIZE*winY*(1+(float)iconNum));
-					mouseIcons.setPos((0.93-SPACING)*winX,ICON_SIZE*winY*(1+(float)iconNum));
+					binderIcons.setPosition((0.93+SPACING)*winX,ICON_SIZE*winY*(1+(float)iconNum));
+					keyIcons.setPosition(0.93*winX,ICON_SIZE*winY*(1+(float)iconNum));
+					mouseIcons.setPosition((0.93-SPACING)*winX,ICON_SIZE*winY*(1+(float)iconNum));
 				}
 				else
 				{
-					binderIcons.setPos(0.95*winX,ICON_SIZE*winY*(1+(float)iconNum));
-					mouseIcons.setPos(0.90*winX,ICON_SIZE*winY*(1+(float)iconNum));
+					binderIcons.setPosition(0.95*winX,ICON_SIZE*winY*(1+(float)iconNum));
+					mouseIcons.setPosition(0.90*winX,ICON_SIZE*winY*(1+(float)iconNum));
 				}
 
 				binderIcons.draw();
@@ -536,13 +608,24 @@ void Scene::drawHoverOverlay()
 
 void Scene::drawProgressAnim() const
 {
-	if(!showProgressAnimation)
+	if(!visControl->state.treeState.isRefreshing())
 		return;
 
+	if(useLighting)
+		glDisable(GL_LIGHTING);
+
+	progressCircle.draw();
 	if(!progressAnimTex.isOK())
+	{
+		if(useLighting)
+			glEnable(GL_LIGHTING);
 		return;
+	}
 
 	progressAnimTex.draw();
+
+	if(useLighting)
+		glEnable(GL_LIGHTING);
 }
 
 void Scene::commitTempCam()
@@ -596,7 +679,6 @@ void Scene::clearAll()
 
 	clearObjs();
 	clearRefObjs();
-	clearBindings();	
 }
 
 void Scene::clearObjs()
@@ -607,13 +689,6 @@ void Scene::clearObjs()
 	lastHovered=-1;
 }
 
-void Scene::clearBindings()
-{
-	//Note that the filter is responsible for cleaning the
-	// bindings. So, we just forget about it, without delete-ing
-	selectionDevices.clear();
-}
-
 
 void Scene::clearRefObjs()
 {
@@ -632,13 +707,6 @@ void Scene::setLightPos(const float *f)
 		lightPosition[ui]=f[ui];
 }
 
-void Scene::setShowProgress(bool show)
-{
-	showProgressAnimation=show;
-	progressAnimTex.resetTime();
-}
-
-
 void Scene::setAspect(float newAspect)
 {
 	outWinAspect=newAspect;
@@ -843,19 +911,13 @@ void Scene::finaliseCam()
 	}
 }
 
-void Scene::addSelectionDevices(const vector<SelectionDevice *> &d)
-{
-	for(unsigned int ui=0;ui<d.size();ui++)
-	{
-#ifdef DEBUG
-		//Ensure that pointers coming in are valid, by attempting to perform an operation on them
-		vector<std::pair<const Filter *,SelectionBinding> > tmp;
-		d[ui]->getModifiedBindings(tmp);
-		tmp.clear();
-#endif
-		selectionDevices.push_back(d[ui]);
-	}
-}
+void Scene::resetProgressAnim()
+{ 	
+	progressAnimTex.resetTime(); 
+	progressCircle.resetTime(); 
+	progressCircle.reset();
+};
+
 
 //Values are in the range [0 1].
 void Scene::applyDevice(float startX, float startY, float curX, float curY,
@@ -871,7 +933,7 @@ void Scene::applyDevice(float startX, float startY, float curX, float curY,
 	ASSERT(lastSelected < objects.size())
 	ASSERT(objects[lastSelected]->canSelect);
 
-	//Grab basis vectors. (up, fowards and 
+	//Grab basis vectors. (up, forwards and 
 	//across from camera view.)
 	//---
 	Point3D forwardsDir,upDir;
@@ -922,6 +984,7 @@ void Scene::applyDevice(float startX, float startY, float curX, float curY,
 	SelectionBinding *binder;
 
 	vector<SelectionBinding*> activeBindings;
+	std::vector<SelectionDevice *> &selectionDevices = visControl->getSelectionDevices();
 	for(unsigned int ui=0;ui<selectionDevices.size();ui++)
 	{
 		if(selectionDevices[ui]->getBinding(
@@ -954,11 +1017,11 @@ void Scene::applyDevice(float startX, float startY, float curX, float curY,
 	//Inform viscontrol about updates, if we have applied any
 	if(activeBindings.size() && permanent)
 	{
-		visControl->setUpdates();
+		visControl->state.treeState.setUpdates();
 		//If the viscontrol is in the middle of an update,
 		//tell it to abort.
-		if(visControl->isRefreshing())
-			visControl->abort();
+		if(visControl->state.treeState.isRefreshing())
+			visControl->state.treeState.setAbort();
 	}
 
 }
@@ -972,19 +1035,6 @@ void Scene::getEffects(vector<const Effect *> &eff) const
 }	
 
 
-void Scene::getModifiedBindings(std::vector<std::pair<const Filter *, SelectionBinding> > &bindings) const
-{
-	for(unsigned int ui=0;ui<selectionDevices.size();ui++)
-		selectionDevices[ui]->getModifiedBindings(bindings);
-}
-
-void Scene::resetModifiedBindings()  
-{
-	for(unsigned int ui=0;ui<selectionDevices.size();ui++)
-		selectionDevices[ui]->resetModifiedBindings();
-}
-
-
 void Scene::setEffectVec(vector<Effect *> &e)
 {
 	clearEffects();
