@@ -1,6 +1,6 @@
 /*
  * 	textures.h - Texture control classes header
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -22,6 +22,15 @@
 
 #include "common/basics.h"
 
+#ifdef CreateDialog
+#undef CreateDialog
+#endif
+
+#ifdef Yield
+#undef Yield
+#endif
+
+
 #ifdef __APPLE__ 
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
