@@ -1,6 +1,6 @@
 /*
  * 	stashdialog.h - "Stash" filter storage edit dialog header
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <wx/wx.h>
 #include <wx/treectrl.h>
 #include <wx/grid.h>
+#include <wx/propgrid/propgrid.h>
 
 // end wxGlade
 
@@ -67,7 +68,7 @@ protected:
     wxStaticText* label_6;
     wxTreeCtrl* treeFilters;
     wxStaticText* label_7;
-    wxCustomPropGrid* gridProperties;
+    wxPropertyGrid* gridProperties;
     wxButton* btnOK;
     // end wxGlade
 
@@ -77,7 +78,7 @@ public:
     virtual void OnListKeyDown(wxListEvent &event); // wxGlade: <event_handler>
     virtual void OnListSelected(wxListEvent &event); // wxGlade: <event_handler>
     virtual void OnTreeSelChange(wxTreeEvent &event); // wxGlade: <event_handler>
-    virtual void OnGridEditor(wxGridEvent &event);
+    virtual void OnGridEditor(wxPropertyGridEvent &event);
 
     virtual void OnBtnRemove(wxCommandEvent &event);
     void ready();
