@@ -1,6 +1,6 @@
 /*
  *	rangeEditDialog.h - Point data export dialog
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -29,7 +29,10 @@
 #include <set>
 
 using std::pair;
-using std::endl;
+using std::vector;
+using std::map;
+using std::set;
+using std::string;
 
 // begin wxGlade: ::extracode
 enum
@@ -215,7 +218,7 @@ RangeEditorDialog::RangeEditorDialog(wxWindow* parent, int id, const wxString& t
     gridRanges = new wxGrid(noteLeftRanges, ID_GRID_RANGES);
     btnRangeIonAdd = new wxButton(noteLeftRanges,wxID_ADD, wxEmptyString);
     btnRangeIonRemove = new wxButton(noteLeftRanges, wxID_REMOVE, wxEmptyString);
-    checkShowOverlay = new wxCheckBox(noteLeftOverlay, ID_CHECK_SHOW_OVERLAY, wxTRANS("Show Overlays"));
+    checkShowOverlay = new wxCheckBox(noteLeftOverlay, ID_CHECK_SHOW_OVERLAY, TRANS("Show Overlays"));
     textOverlayCmpnt = new wxTextCtrl(noteLeftOverlay, ID_TEXT_FILTER_CMPNT, wxEmptyString,
     						wxDefaultPosition,wxDefaultSize,wxTE_PROCESS_ENTER);
     listOverlay = new wxCheckListBox(noteLeftOverlay, ID_LIST_OVERLAY, wxDefaultPosition, wxDefaultSize, 0);
@@ -240,26 +243,16 @@ RangeEditorDialog::RangeEditorDialog(wxWindow* parent, int id, const wxString& t
     checkShowOverlay->SetValue(true);
 
     haveSetTextFocus=false;
-    textOverlayCmpnt->SetValue(wxTRANS("e.g. H2O"));
+    textOverlayCmpnt->SetValue(TRANS("e.g. H2O"));
 
-#if wxCHECK_VERSION(2, 9, 0)
     textOverlayCmpnt->Bind(wxEVT_SET_FOCUS, &RangeEditorDialog::OnTextOverlaySetFocus, this);
-#else
-    textOverlayCmpnt->Connect(wxID_ANY,
-                 wxEVT_SET_FOCUS,
-		   wxFocusEventHandler(RangeEditorDialog::OnTextOverlaySetFocus), NULL, this);
-#endif
 }
 
 
 
 RangeEditorDialog::~RangeEditorDialog()
 {
-#if wxCHECK_VERSION(2, 9, 0)
     textOverlayCmpnt->Unbind(wxEVT_SET_FOCUS, &RangeEditorDialog::OnTextOverlaySetFocus, this);
-#else
-    textOverlayCmpnt->Disconnect();
-#endif
 }
 
 
@@ -272,13 +265,8 @@ BEGIN_EVENT_TABLE(RangeEditorDialog, wxDialog)
     EVT_TEXT(ID_TEXT_FILTER_CMPNT,RangeEditorDialog::OnTextOverlay)
     EVT_TEXT_ENTER(ID_TEXT_FILTER_CMPNT,RangeEditorDialog::OnTextOverlayEnter)
     EVT_CHECKBOX(ID_CHECK_SHOW_OVERLAY, RangeEditorDialog::OnCheckShowOverlay)
-#if wxCHECK_VERSION(2,9,0)
     EVT_GRID_CMD_CELL_CHANGED(ID_GRID_RANGES, RangeEditorDialog::OnGridRangesCellChange)
     EVT_GRID_CMD_CELL_CHANGED(ID_GRID_IONS, RangeEditorDialog::OnGridIonsCellChange)
-#else
-    EVT_GRID_CMD_CELL_CHANGE(ID_GRID_RANGES, RangeEditorDialog::OnGridRangesCellChange)
-    EVT_GRID_CMD_CELL_CHANGE(ID_GRID_IONS, RangeEditorDialog::OnGridIonsCellChange)
-#endif
     EVT_GRID_CMD_CELL_LEFT_CLICK(ID_GRID_RANGES,RangeEditorDialog::OnGridRangeClick) 
     EVT_GRID_CMD_CELL_LEFT_CLICK(ID_GRID_IONS,RangeEditorDialog::OnGridIonClick) 
     EVT_GRID_CMD_EDITOR_SHOWN(ID_GRID_RANGES,RangeEditorDialog::OnGridRangesEditorShown)
@@ -288,7 +276,7 @@ BEGIN_EVENT_TABLE(RangeEditorDialog, wxDialog)
     EVT_CHECKLISTBOX(ID_LIST_OVERLAY, RangeEditorDialog::OnListOverlayCheck)
     EVT_BUTTON(wxID_OK, RangeEditorDialog::OnBtnOK)
     EVT_BUTTON(wxID_CANCEL, RangeEditorDialog::OnBtnCancel)
-    EVT_SPLITTER_UNSPLIT(ID_SPLIT_LEFTRIGHT, RangeEditorDialog::OnSashVerticalUnsplit)
+    EVT_SPLITTER_DCLICK(ID_SPLIT_LEFTRIGHT, RangeEditorDialog::OnSashVerticalDClick)
     // end wxGlade
 END_EVENT_TABLE();
 
@@ -434,13 +422,11 @@ void RangeEditorDialog::setCurrentRange(size_t forceSelected)
 			currentRange=0;
 			return;
 		}
-		cerr << "Selected item not wxNOT_FOUND" << endl;
 
 		curPlotID=listToPlotIDs[selectedItem];
 	}
 	else
 	{
-		cerr << "Not force selected" << endl;
 		curPlotID=listToPlotIDs[forceSelected];
 	}
 	
@@ -518,7 +504,7 @@ void RangeEditorDialog::generateListEntries()
 		unsigned int plotID;
 		plotID = plotIDs[ui];
 
-		std::wstring title;
+		std::string title;
 		title=plotWrap.getTitle(plotID);
 
 		//Only use plots from spectra
@@ -526,9 +512,9 @@ void RangeEditorDialog::generateListEntries()
 			continue;	
 
 		//Append the plot to the list in the user interface,
-		// with the plot Id embeded in the element
+		// with the plot Id embedded in the element
 		int idx;
-		idx=listPlots->Append(wxStr(title));
+		idx=listPlots->Append((title));
 		listToPlotIDs[idx]=plotIDs[ui];
 	}
 
@@ -549,7 +535,7 @@ void RangeEditorDialog::generateOverlayList(const vector<OVERLAY_DATA> &overlays
 
 	for(size_t ui=0;ui<overlays.size();ui++)
 	{
-		listOverlay->Insert(wxStr(overlays[ui].title),ui);
+		listOverlay->Insert((overlays[ui].title),ui);
 		listOverlay->Check(ui,overlays[ui].enabled);
 	}
 
@@ -572,10 +558,10 @@ void RangeEditorDialog::generateIonEntries(size_t rowVisibleHint)
 		gridIons->DeleteRows(0,gridIons->GetNumberRows());
 	
 	gridIons->AppendCols(4);
-	gridIons->SetColLabelValue(ION_COL_PLOT,wxTRANS("Plot"));
-	gridIons->SetColLabelValue(ION_COL_SHORTNAME,wxTRANS("Short Name"));
-	gridIons->SetColLabelValue(ION_COL_LONGNAME,wxTRANS("Long Name"));
-	gridIons->SetColLabelValue(ION_COL_COLOUR,wxTRANS("Colour"));
+	gridIons->SetColLabelValue(ION_COL_PLOT,TRANS("Plot"));
+	gridIons->SetColLabelValue(ION_COL_SHORTNAME,TRANS("Short Name"));
+	gridIons->SetColLabelValue(ION_COL_LONGNAME,TRANS("Long Name"));
+	gridIons->SetColLabelValue(ION_COL_COLOUR,TRANS("Colour"));
 	//--
 	
 	
@@ -594,7 +580,7 @@ void RangeEditorDialog::generateIonEntries(size_t rowVisibleHint)
 	}
 	
 	
-	std::wstring title;
+	std::string title;
 	title=plotWrap.getTitle(curPlot);
 
 	//Colour to  use for incomplete ions/ranges
@@ -613,12 +599,12 @@ void RangeEditorDialog::generateIonEntries(size_t rowVisibleHint)
 		gridIonIds[uj]=curIonRow;
 
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_PLOT,wxStr(title));
+				ION_COL_PLOT,(title));
 
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_SHORTNAME,wxStr(currentRange->getName(uj)));
+				ION_COL_SHORTNAME,(currentRange->getName(uj)));
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_LONGNAME,wxStr(currentRange->getName(uj,false)));
+				ION_COL_LONGNAME,(currentRange->getName(uj,false)));
 		
 		//set the colour
 		wxGridCellAttr *attr = gridIons->GetOrCreateCellAttr(curIonRow,ION_COL_COLOUR);
@@ -641,12 +627,12 @@ void RangeEditorDialog::generateIonEntries(size_t rowVisibleHint)
 	for(size_t ui=0;ui<incompleteIons.size();ui++)
 	{
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_PLOT,wxStr(title));
+				ION_COL_PLOT,(title));
 
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_SHORTNAME,wxStr(incompleteIons[ui].getShortName()));
+				ION_COL_SHORTNAME,(incompleteIons[ui].getShortName()));
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_LONGNAME,wxStr(incompleteIons[ui].getLongName()));
+				ION_COL_LONGNAME,(incompleteIons[ui].getLongName()));
 		
 		//set the colour
 		wxGridCellAttr *attr = gridIons->GetOrCreateCellAttr(curIonRow,ION_COL_COLOUR);
@@ -706,10 +692,10 @@ void RangeEditorDialog::generateRangeEntries(size_t rowVisibleHint)
 		gridRanges->DeleteRows(0,gridRanges->GetNumberRows());
 	
 	gridRanges->AppendCols(4);
-	gridRanges->SetColLabelValue(0,wxTRANS("Plot"));
-	gridRanges->SetColLabelValue(1,wxTRANS("Ion"));
-	gridRanges->SetColLabelValue(2,wxTRANS("Start"));
-	gridRanges->SetColLabelValue(3,wxTRANS("End"));
+	gridRanges->SetColLabelValue(0,TRANS("Plot"));
+	gridRanges->SetColLabelValue(1,TRANS("Ion"));
+	gridRanges->SetColLabelValue(2,TRANS("Start"));
+	gridRanges->SetColLabelValue(3,TRANS("End"));
 	//---
 
 	gridRangeIds.clear();
@@ -730,7 +716,7 @@ void RangeEditorDialog::generateRangeEntries(size_t rowVisibleHint)
 	wxColour incomplColour;
 	//A light blue colour
 	incomplColour.Set(162,162,255);
-	std::wstring title;
+	std::string title;
 	title=plotWrap.getTitle(curPlot);
 	
 	//Fill in the range grid
@@ -745,14 +731,14 @@ void RangeEditorDialog::generateRangeEntries(size_t rowVisibleHint)
 		std::string ionName;
 		ionName=currentRange->getName(currentRange->getIonID((unsigned int)ui));
 
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_PLOT,wxStr(title));
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_PARENT_ION,wxStr(ionName));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_PLOT,(title));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_PARENT_ION,(ionName));
 
 		std::string tmpStr;
 		stream_cast(tmpStr,rangeBound.first);
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_START,wxStr(tmpStr));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_START,(tmpStr));
 		stream_cast(tmpStr,rangeBound.second);
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_END,wxStr(tmpStr));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_END,(tmpStr));
 
 		curRangeRow++;
 	}
@@ -769,14 +755,14 @@ void RangeEditorDialog::generateRangeEntries(size_t rowVisibleHint)
 		std::string ionName;
 		ionName=incompleteRanges[ui].getIonName();
 
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_PLOT,wxStr(title));
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_PARENT_ION,wxStr(ionName));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_PLOT,(title));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_PARENT_ION,(ionName));
 
 		std::string tmpStr;
 		stream_cast(tmpStr,incompleteRanges[ui].getStart());
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_START,wxStr(tmpStr));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_START,(tmpStr));
 		stream_cast(tmpStr,incompleteRanges[ui].getEnd());
-		gridRanges->SetCellValue(curRangeRow,RNG_COL_END,wxStr(tmpStr));
+		gridRanges->SetCellValue(curRangeRow,RNG_COL_END,(tmpStr));
 
 		for(size_t uj=0;uj<RNG_COL_ENUM_END; uj++)
 			gridRanges->SetCellBackgroundColour(curRangeRow,uj,incomplColour);
@@ -1118,7 +1104,7 @@ void RangeEditorDialog::OnGridRangesCellChange(wxGridEvent &event)
 				return;
 			}
 			
-			//Disallow inversio of range start/end
+			//Disallow inversion of range start/end
 			if(f >=currentRange->getRange(rangeId).second)
 			{
 				event.Veto();
@@ -1139,7 +1125,7 @@ void RangeEditorDialog::OnGridRangesCellChange(wxGridEvent &event)
 				return;
 			}
 			
-			//Disallow inversoin of range start/end
+			//Disallow inversion of range start/end
 			if(f <=currentRange->getRange(rangeId).first)
 			{
 				event.Veto();
@@ -1268,16 +1254,11 @@ void RangeEditorDialog::OnBtnRangeIonAdd(wxCommandEvent &event)
 		!gridRanges->GetNumberRows() || !gridIons->GetNumberRows())
 	{
 		wxArrayString wxStrs;
-		wxStrs.Add(wxCStr("Ion"));
-		wxStrs.Add(wxCStr("Range"));
+		wxStrs.Add(("Ion"));
+		wxStrs.Add(("Range"));
 
-#if wxCHECK_VERSION(2, 9, 0)
-		wxSingleChoiceDialog *wxD = new wxSingleChoiceDialog(this, wxTRANS("Range or ion?"),
-				wxTRANS("Select type to add"),wxStrs,(void **)NULL,wxDEFAULT_DIALOG_STYLE|wxOK|wxCENTRE);
-#else
-		wxSingleChoiceDialog *wxD = new wxSingleChoiceDialog(this, wxTRANS("Range or ion?"),
-				wxTRANS("Select type to add"),wxStrs,NULL,wxDEFAULT_DIALOG_STYLE|wxOK|wxCENTRE);
-#endif
+		wxSingleChoiceDialog *wxD = new wxSingleChoiceDialog(this, TRANS("Range or ion?"),
+				TRANS("Select type to add"),wxStrs,(void **)NULL,wxDEFAULT_DIALOG_STYLE|wxOK|wxCENTRE);
 
 		wxD->ShowModal();
 
@@ -1438,7 +1419,7 @@ void RangeEditorDialog::OnListOverlayKeyDown(wxListEvent &event)
 	plotPanel->Refresh();
 }
 
-void RangeEditorDialog::OnSashVerticalUnsplit(wxSplitterEvent &event)
+void RangeEditorDialog::OnSashVerticalDClick(wxSplitterEvent &event)
 {
 	event.Veto();
 }
@@ -1558,16 +1539,16 @@ void RangeEditorDialog::OnTextOverlayEnter(wxCommandEvent &event)
 void RangeEditorDialog::set_properties()
 {
     // begin wxGlade: RangeEditorDialog::set_properties
-    SetTitle(wxTRANS("Range Editor"));
+    SetTitle(TRANS("Range Editor"));
     gridRanges->CreateGrid(0, 3);
     gridIons->CreateGrid(0, 3);
 
-    checkShowOverlay->SetToolTip(wxTRANS("Enable or disable all overlays"));
-    listOverlay->SetToolTip(wxTRANS("Entered overlays, use delete to remove"));
-    listPlots->SetToolTip(wxTRANS("Available plots for ranging"));
-    textOverlayCmpnt->SetToolTip(wxTRANS("Enter species to display as overlay, e.g. SiO2"));
-    gridRanges->SetToolTip(wxTRANS("Editable ranges"));
-    gridIons->SetToolTip(wxTRANS("Editable ions"));
+    checkShowOverlay->SetToolTip(TRANS("Enable or disable all overlays"));
+    listOverlay->SetToolTip(TRANS("Entered overlays, use delete to remove"));
+    listPlots->SetToolTip(TRANS("Available plots for ranging"));
+    textOverlayCmpnt->SetToolTip(TRANS("Enter species to display as overlay, e.g. SiO2"));
+    gridRanges->SetToolTip(TRANS("Editable ranges"));
+    gridIons->SetToolTip(TRANS("Editable ions"));
     // end wxGlade
 }
 
@@ -1602,9 +1583,9 @@ void RangeEditorDialog::do_layout()
     sizerOverlay->Add(sizerOverlayContainer, 1, wxEXPAND, 0);
     sizerOverlayPane->Add(sizerOverlay, 1, wxEXPAND, 0);
     noteLeftOverlay->SetSizer(sizerOverlayPane);
-    notebookLeft->AddPage(noteLeftPlots, wxTRANS("Plots"));
-    notebookLeft->AddPage(noteLeftRanges, wxTRANS("Ranges"));
-    notebookLeft->AddPage(noteLeftOverlay, wxTRANS("Overlay"));
+    notebookLeft->AddPage(noteLeftPlots, TRANS("Plots"));
+    notebookLeft->AddPage(noteLeftRanges, TRANS("Ranges"));
+    notebookLeft->AddPage(noteLeftOverlay, TRANS("Overlay"));
     sizerNote->Add(notebookLeft, 1, wxEXPAND, 0);
     panelSplitLeft->SetSizer(sizerNote);
     sizerRight->Add(plotPanel, 1, wxEXPAND, 0);
