@@ -103,12 +103,19 @@ BasicGLPane::BasicGLPane(wxWindow* parent) : wxGLCanvas(parent, wxID_ANY,  attri
 	lastMoveShiftDown=false;
 	selectionMode=false;
 	lastKeyFlags=lastMouseFlags=0;
+
+#ifdef __APPLE__
+	requireContextUpdate=false;
+#endif
+
 }
 
 BasicGLPane::~BasicGLPane()
 {
 	keyDoubleTapTimer->Stop();
 	delete keyDoubleTapTimer;
+	if(context)
+		delete context;
 }
 
 bool BasicGLPane::displaySupported() const
@@ -210,6 +217,13 @@ void BasicGLPane::forceRedraw()
 	wxPaintEvent ptEvent;
 	wxPostEvent(this,ptEvent);
 
+#ifdef WIN32
+	//Hack for windows. Does not redraw otherwise.
+	// Refresh and Update in tandom dont work.
+	Show(false);
+	Show(true);
+#endif
+
 }
 
 // some useful events to use
@@ -635,7 +649,7 @@ void BasicGLPane::keyPressed(wxKeyEvent& event)
 		}
 		break;
 		default:
-			event.Skip();
+			event.Skip(true);
 	}
 }
 
@@ -658,6 +672,7 @@ void BasicGLPane::keyReleased(wxKeyEvent& event)
 	if(event.ShiftDown())
 		cameraMoveRate*=5;
 
+	bool update=true;
 	switch(event.GetKeyCode())
 	{
 		case '-':
@@ -687,10 +702,12 @@ void BasicGLPane::keyReleased(wxKeyEvent& event)
 			break;
 		}
 		default:
-			event.Skip();
+			event.Skip(true);
+			update=false;
 	}
 
-	Refresh();
+	if(update)
+		Refresh();
 }
 
  
@@ -699,6 +716,10 @@ void BasicGLPane::resized(wxSizeEvent& evt)
 	prepare3DViewport(0,0,getWidth(),getHeight()); 
 	wxClientDC *dc=new wxClientDC(this);
 	Refresh();
+
+#ifdef __APPLE__
+	requireContextUpdate=true;
+#endif
 	delete dc;
 }
  
@@ -764,6 +785,9 @@ void BasicGLPane::render( wxPaintEvent& evt )
 	{
 		context = new wxGLContext(this);
 		SetCurrent(*context);
+#ifdef __APPLE__
+		requireContextUpdate=false;
+#endif	
 	}
 
 	if(!paneInitialised)
@@ -772,6 +796,19 @@ void BasicGLPane::render( wxPaintEvent& evt )
 		prepare3DViewport(0,0,getWidth(),getHeight()); 
 	}
 
+//Apple requires a context update on each resize, for some reason
+// https://developer.apple.com/library/mac/documentation/GraphicsImaging/Conceptual/OpenGL-MacProgGuide/opengl_contexts/opengl_contexts.html
+//and
+// https://forums.wxwidgets.org/viewtopic.php?f=23&t=41592&p=168346
+#ifdef __APPLE__
+	if(requireContextUpdate)
+	{
+		SetCurrent(*context);
+		prepare3DViewport(0,0,getWidth(),getHeight()); 
+		requireContextUpdate=false;
+	}
+#endif
+
 	wxPaintDC(this); 
 	currentScene->draw();
 	glFlush();
@@ -1044,17 +1081,21 @@ bool BasicGLPane::saveImage(unsigned int width, unsigned int height,
 		//FIXME: HACK - using "blue screen" effect
 		//don't use background as mask colour.
 		// use depth buffer or gl alpha
-		const unsigned char mask[3] = {(unsigned char)rClear*255.0f,
-				(unsigned char)gClear*255.0f,(unsigned char)bClear*255.0f};
+		unsigned char clear[3];
+		clear[0] = (unsigned char)rClear*255.0f;
+		clear[1] = (unsigned char)gClear*255.0f;
+		clear[2] = (unsigned char)bClear*255.0f;
+		const unsigned char *mask = clear;
 		copyRGBAtoWXImage(width,height,imageBuffer,imageOverlay,mask);
 
 		free(imageBuffer);
 
 		combineWxImage(*image,imageOverlay);
+
+		//Free the tile buffer
+		trDelete(tr);
 	}
 
-	//Free the tile buffer
-	trDelete(tr);
 	
 	//--------------	
 	bool isOK=image->SaveFile(filename,wxBITMAP_TYPE_PNG);
