@@ -1,6 +1,6 @@
 /*
  *	mathglPanel.h - WxWidgets plotting panelf or interaction with mathgl
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -22,10 +22,7 @@
 
 #include "backend/plot.h"
 
-#ifndef USE_MGL2
-	#include <mgl/mgl_zb.h>
-	#undef is_nan
-#endif
+#include <vector>
 
 // begin wxGlade: ::extracode
 // end wxGlade
@@ -48,7 +45,7 @@ private:
 	wxBitmap imageCacheBmp;	
 	
 	
-	vector<pair<wxWindow*,UpdateHandler> > updateHandlers;
+	std::vector<std::pair<wxWindow*,UpdateHandler> > updateHandlers;
 
 	//Current mouse position
 	wxPoint curMouse;
@@ -68,6 +65,7 @@ private:
 	wxPoint draggingStart,draggingCurrent;
 	//!Original bounds during panning operations.
 	float origPanMinX, origPanMaxX; //1D and 2D actions
+	float origPanMinY, origPanMaxY; //2D actions
 
 	//!region used at mouse down
 	unsigned int startMouseRegion,startMousePlot,regionMoveType;
@@ -78,11 +76,9 @@ private:
 	bool limitInteract;
 
 	//!Pointer to the plot data holding class
+	// TODO: Make const, as this should be owned by the analysis state
 	PlotWrapper *thePlot;
 	
-	//!Should we take ownership of deleting the plot pointer
-	bool ownPlotPtr;
-
 	//!True if regions should update themselves
 	bool regionSelfUpdate;
 
@@ -90,11 +86,8 @@ private:
 	bool  plotIsLogarithmic;
 
 	//!Pointer to the mathgl renderer
-#ifdef USE_MGL2
 	mglGraph *gr;	
-#else
-	mglGraphZB *gr;	
-#endif
+	
 	//!Caching check vector for plot visibility
 	std::vector<unsigned int> lastVisible;
 
@@ -122,6 +115,13 @@ private:
 	//Action to perform when showing 1D plots and mouse down event occurs
 	void oneDMouseDownAction(bool leftDown,bool middleMouseDown,
 		bool alternateDown, int dragX,int dragY);
+	
+	//Action to perform when showing 2D plots and mouse down event occurs
+	void twoDMouseDownAction(bool leftDown,bool middleMouseDown,
+		bool alternateDown, int dragX,int dragY);
+
+	//Update plot bounds with any user panning action
+	void setPanCoords() const;
 
 	bool readyForInput() const;
 
@@ -160,7 +160,7 @@ public:
 	//Returns the ID of the last edited region
 	void getLastEdited(size_t &lastPlot,size_t &lastRegion) const { lastRegion=lastEditedRegion; lastPlot=lastEditedPlot;};
 	//Add a callback for the given window that will be called when the panel needs updating
-	void registerUpdateHandler(wxWindow *w, UpdateHandler handler) { updateHandlers.push_back(make_pair(w,handler));};
+	void registerUpdateHandler(wxWindow *w, UpdateHandler handler) { updateHandlers.push_back(std::make_pair(w,handler));};
 
 	//Resize event for window
 	void resized(wxSizeEvent& evt);
