@@ -1,6 +1,6 @@
 /*
  *	filtertesting.cpp - unit testing implementation for filter code
- *	Copyright (C) 2013, D Haley 
+ *	Copyright (C) 2015, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -15,6 +15,14 @@
  *	You should have received a copy of the GNU General Public License
  *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+#include <string>
+#include <list>
+#include <set>
+#include <fstream>
+#include <iostream>
+
+
+using namespace std;
 
 //!Run each filter through its own unit test function
 bool filterTests();
@@ -57,7 +65,12 @@ bool testFilterTree(const FilterTree &f,
 	std::vector<std::pair<const Filter *, string > > consoleMessages;
 
 	ProgressData prog;
-	if(f.refreshFilterTree(outData,devices,consoleMessages,prog,dummyCallback))
+#ifdef  HAVE_CPP_1X
+	ATOMIC_BOOL wantAbort(false);
+#else
+	ATOMIC_BOOL wantAbort=false;
+#endif
+	if(f.refreshFilterTree(outData,devices,consoleMessages,prog,wantAbort))
 	{
 		f.safeDeleteFilterList(outData);
 		return false;
@@ -157,7 +170,7 @@ bool filterCloneTests()
 			wxString wxs,tmpStr;
 
 			tmpStr=wxT("3Depict-unit-test-a");
-			tmpStr=tmpStr+wxStr(f->getUserString());
+			tmpStr=tmpStr+(f->getUserString());
 			
 			wxs= wxFileName::CreateTempFileName(tmpStr);
 			sOrig=stlStr(wxs);
@@ -176,7 +189,7 @@ bool filterCloneTests()
 
 			//write out file from cloned object
 			tmpStr=wxT("3Depict-unit-test-b");
-			tmpStr=tmpStr+wxStr(f->getUserString());
+			tmpStr=tmpStr+(f->getUserString());
 			wxs= wxFileName::CreateTempFileName(tmpStr);
 			sClone=stlStr(wxs);
 			fileOut.open(sClone.c_str());
@@ -201,11 +214,7 @@ bool filterCloneTests()
 
 		wxArrayString stdOut;
 		long res;
-#if wxCHECK_VERSION(2,9,0)
-		res=wxExecute(wxStr(command),stdOut, wxEXEC_BLOCK);
-#else
-		res=wxExecute(wxStr(command),stdOut);
-#endif
+		res=wxExecute((command),stdOut, wxEXEC_BLOCK);
 
 
 		string comment = f->getUserString() + string(" Orig: ")+ sOrig + string (" Clone:") +sClone+
@@ -247,19 +256,16 @@ bool filterCloneTests()
 			g->writeState(fileOut,STATE_FORMAT_XML);
 
 			//Re-run diff
-#if wxCHECK_VERSION(2,9,0)
-			res=wxExecute(wxStr(command),stdOut, wxEXEC_BLOCK);
-#else
-			res=wxExecute(wxStr(command),stdOut);
-#endif
+			res=wxExecute((command),stdOut, wxEXEC_BLOCK);
+			
 			comment = f->getUserString() + string("Orig: ")+ sOrig + string (" Clone:") +sClone+
 				string("Read-back filter output was different... (or diff not around?)");
 			TEST(res==0,comment.c_str());
 		}
 		//----
 		//clean up
-		wxRemoveFile(wxStr(sOrig));
-		wxRemoveFile(wxStr(sClone));
+		wxRemoveFile((sOrig));
+		wxRemoveFile((sClone));
 
 		delete f;
 		delete g;
@@ -428,15 +434,19 @@ bool filterTreeTests()
 				throw false;
 			
 			TEST(!fTree.loadXML(nodePtr,cerr,""),"Tree load test");
+
+		
+
+			xmlFreeDoc(doc);	
 			//-----
 		}
 		catch(bool)
 		{
 			WARN(false,"Couldn't run XML reparse of output file - write permission?" );
-			wxRemoveFile(wxStr(tmpName));
+			wxRemoveFile((tmpName));
 			return true;
 		}
-		wxRemoveFile(wxStr(tmpName));
+		wxRemoveFile((tmpName));
 	}
 	else
 	{
@@ -471,7 +481,7 @@ bool filterRefreshNoOut()
 		return true;
 	}
 
-	//Write out some useable data
+	//Write out some usable data
 	f << "1 2 3 4" << std::endl;
 	f << "2 1 3 5" << std::endl;
 	f << "3 2 1 6" << std::endl;
@@ -502,7 +512,7 @@ bool filterRefreshNoOut()
 	TEST(outData.empty(),"External program refresh test");
 	fTree.safeDeleteFilterList(outData);
 
-	wxRemoveFile(wxStr(strData));
+	wxRemoveFile((strData));
 
 	return true;
 }
