@@ -1,6 +1,6 @@
 /*
  * wxcommon.h  - Common wxwidgets header stuff
- * Copyright (C) 2013  D Haley
+ * Copyright (C) 2015  D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +26,6 @@
 #include "common/basics.h"
 #include "backend/tree.hh"
 
-#define wxCStr(a) wxString(a,*wxConvCurrent)
-#define wxStr(a) wxString(a.c_str(),*wxConvCurrent)
-
 
 //This function is adapted from
 //http://www.creatis.insa-lyon.fr/software/public/creatools/bbtk/v0_9_2/doc/doxygen/bbtk/bbtkWx_8h-source.html
@@ -132,9 +129,19 @@ std::string locateDataFile(const char *name);
 //Custom event for remote update thread posting
 extern wxEventType RemoteUpdateAvailEvent; 
 
+//Custom event for signalling that a refresh is completed
+extern wxEventType RefreshCompleteEvent; 
+
 //Return true IFF process ID and process name match running process
 bool processMatchesName(size_t processID, const std::string &procName);
 
+//Copy data into a wx image from an unpadded RGBA block of given width/eight
+// image sould already have been initialised, with RGBA and size
+void copyRGBAtoWXImage(unsigned int width, unsigned int height,
+		const unsigned char *rgbaBuf, wxImage &image, const unsigned char *mask);
+
+//Combine an overlay using the alpha channel
+void combineWxImage(wxImage &base, const wxImage &overlay);
 
 //!Remote version thread checker, downloads RSS file from remote system and then
 // parses the file for the latest remote version number
